# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .drg_attachment_network_update_details import DrgAttachmentNetworkUpdateDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VcnDrgAttachmentNetworkUpdateDetails(DrgAttachmentNetworkUpdateDetails):
    """
    Specifies the update details for the VCN attachment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VcnDrgAttachmentNetworkUpdateDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.VcnDrgAttachmentNetworkUpdateDetails.type` attribute
        of this class is ``VCN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this VcnDrgAttachmentNetworkUpdateDetails.
            Allowed values for this property are: "VCN"
        :type type: str

        :param route_table_id:
            The value to assign to the route_table_id property of this VcnDrgAttachmentNetworkUpdateDetails.
        :type route_table_id: str

        """
        self.swagger_types = {
            'type': 'str',
            'route_table_id': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'route_table_id': 'routeTableId'
        }

        self._type = None
        self._route_table_id = None
        self._type = 'VCN'

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this VcnDrgAttachmentNetworkUpdateDetails.
        This is the `OCID`__ of the route table that is used to route the traffic as it enters a VCN through this attachment.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :return: The route_table_id of this VcnDrgAttachmentNetworkUpdateDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this VcnDrgAttachmentNetworkUpdateDetails.
        This is the `OCID`__ of the route table that is used to route the traffic as it enters a VCN through this attachment.

        For information about why you would associate a route table with a DRG attachment, see:

          * `Transit Routing: Access to Multiple VCNs in Same Region`__
          * `Transit Routing: Private Access to Oracle Services`__

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitrouting.htm
        __ https://docs.cloud.oracle.com/iaas/Content/Network/Tasks/transitroutingoracleservices.htm


        :param route_table_id: The route_table_id of this VcnDrgAttachmentNetworkUpdateDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .dimension_value_details import DimensionValueDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JmesPathDimensionValue(DimensionValueDetails):
    """
    Evaluated type of dimension value.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JmesPathDimensionValue object with values from keyword arguments. The default value of the :py:attr:`~oci.sch.models.JmesPathDimensionValue.kind` attribute
        of this class is ``jmesPath`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param kind:
            The value to assign to the kind property of this JmesPathDimensionValue.
            Allowed values for this property are: "jmesPath", "static"
        :type kind: str

        :param path:
            The value to assign to the path property of this JmesPathDimensionValue.
        :type path: str

        """
        self.swagger_types = {
            'kind': 'str',
            'path': 'str'
        }

        self.attribute_map = {
            'kind': 'kind',
            'path': 'path'
        }

        self._kind = None
        self._path = None
        self._kind = 'jmesPath'

    @property
    def path(self):
        """
        **[Required]** Gets the path of this JmesPathDimensionValue.
        The location to use for deriving the dimension value (evaluated).
        The path must start with `logContent` in an acceptable notation style with supported `JMESPath selectors`__: expression with dot and index operator (`.` and `:func:`metric_data_details`.
        The returned value depends on the results of evaluation.
        If the evaluated value is valid, then the evaluated value is returned without double quotes. (Any front or trailing double quotes are trimmed before returning the value. For example, the evaluated value `\"compartmentId\"` is returned as `compartmentId`.)
        If the evaluated value is invalid, then the returned value is `SCH_EVAL_INVALID_VALUE`.
        If the evaluated value is empty, then the returned value is `SCH_EVAL_VALUE_EMPTY`.

        __ https://jmespath.org/specification.html


        :return: The path of this JmesPathDimensionValue.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this JmesPathDimensionValue.
        The location to use for deriving the dimension value (evaluated).
        The path must start with `logContent` in an acceptable notation style with supported `JMESPath selectors`__: expression with dot and index operator (`.` and `:func:`metric_data_details`.
        The returned value depends on the results of evaluation.
        If the evaluated value is valid, then the evaluated value is returned without double quotes. (Any front or trailing double quotes are trimmed before returning the value. For example, the evaluated value `\"compartmentId\"` is returned as `compartmentId`.)
        If the evaluated value is invalid, then the returned value is `SCH_EVAL_INVALID_VALUE`.
        If the evaluated value is empty, then the returned value is `SCH_EVAL_VALUE_EMPTY`.

        __ https://jmespath.org/specification.html


        :param path: The path of this JmesPathDimensionValue.
        :type: str
        """
        self._path = path

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_summary import HostConfigurationSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EmManagedExternalHostConfigurationSummary(HostConfigurationSummary):
    """
    Configuration summary of a EM Managed External host.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EmManagedExternalHostConfigurationSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.EmManagedExternalHostConfigurationSummary.entity_source` attribute
        of this class is ``EM_MANAGED_EXTERNAL_HOST`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param host_insight_id:
            The value to assign to the host_insight_id property of this EmManagedExternalHostConfigurationSummary.
        :type host_insight_id: str

        :param entity_source:
            The value to assign to the entity_source property of this EmManagedExternalHostConfigurationSummary.
            Allowed values for this property are: "MACS_MANAGED_EXTERNAL_HOST", "EM_MANAGED_EXTERNAL_HOST", "PE_COMANAGED_HOST"
        :type entity_source: str

        :param compartment_id:
            The value to assign to the compartment_id property of this EmManagedExternalHostConfigurationSummary.
        :type compartment_id: str

        :param host_name:
            The value to assign to the host_name property of this EmManagedExternalHostConfigurationSummary.
        :type host_name: str

        :param platform_type:
            The value to assign to the platform_type property of this EmManagedExternalHostConfigurationSummary.
            Allowed values for this property are: "LINUX", "SOLARIS", "SUNOS", "ZLINUX"
        :type platform_type: str

        :param platform_version:
            The value to assign to the platform_version property of this EmManagedExternalHostConfigurationSummary.
        :type platform_version: str

        :param platform_vendor:
            The value to assign to the platform_vendor property of this EmManagedExternalHostConfigurationSummary.
        :type platform_vendor: str

        :param total_cpus:
            The value to assign to the total_cpus property of this EmManagedExternalHostConfigurationSummary.
        :type total_cpus: int

        :param total_memory_in_gbs:
            The value to assign to the total_memory_in_gbs property of this EmManagedExternalHostConfigurationSummary.
        :type total_memory_in_gbs: float

        :param cpu_architecture:
            The value to assign to the cpu_architecture property of this EmManagedExternalHostConfigurationSummary.
        :type cpu_architecture: str

        :param cpu_cache_in_mbs:
            The value to assign to the cpu_cache_in_mbs property of this EmManagedExternalHostConfigurationSummary.
        :type cpu_cache_in_mbs: float

        :param cpu_vendor:
            The value to assign to the cpu_vendor property of this EmManagedExternalHostConfigurationSummary.
        :type cpu_vendor: str

        :param cpu_frequency_in_mhz:
            The value to assign to the cpu_frequency_in_mhz property of this EmManagedExternalHostConfigurationSummary.
        :type cpu_frequency_in_mhz: float

        :param cpu_implementation:
            The value to assign to the cpu_implementation property of this EmManagedExternalHostConfigurationSummary.
        :type cpu_implementation: str

        :param cores_per_socket:
            The value to assign to the cores_per_socket property of this EmManagedExternalHostConfigurationSummary.
        :type cores_per_socket: int

        :param total_sockets:
            The value to assign to the total_sockets property of this EmManagedExternalHostConfigurationSummary.
        :type total_sockets: int

        :param threads_per_socket:
            The value to assign to the threads_per_socket property of this EmManagedExternalHostConfigurationSummary.
        :type threads_per_socket: int

        :param is_hyper_threading_enabled:
            The value to assign to the is_hyper_threading_enabled property of this EmManagedExternalHostConfigurationSummary.
        :type is_hyper_threading_enabled: bool

        :param defined_tags:
            The value to assign to the defined_tags property of this EmManagedExternalHostConfigurationSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this EmManagedExternalHostConfigurationSummary.
        :type freeform_tags: dict(str, str)

        :param enterprise_manager_identifier:
            The value to assign to the enterprise_manager_identifier property of this EmManagedExternalHostConfigurationSummary.
        :type enterprise_manager_identifier: str

        :param enterprise_manager_bridge_id:
            The value to assign to the enterprise_manager_bridge_id property of this EmManagedExternalHostConfigurationSummary.
        :type enterprise_manager_bridge_id: str

        :param exadata_details:
            The value to assign to the exadata_details property of this EmManagedExternalHostConfigurationSummary.
        :type exadata_details: oci.opsi.models.ExadataDetails

        """
        self.swagger_types = {
            'host_insight_id': 'str',
            'entity_source': 'str',
            'compartment_id': 'str',
            'host_name': 'str',
            'platform_type': 'str',
            'platform_version': 'str',
            'platform_vendor': 'str',
            'total_cpus': 'int',
            'total_memory_in_gbs': 'float',
            'cpu_architecture': 'str',
            'cpu_cache_in_mbs': 'float',
            'cpu_vendor': 'str',
            'cpu_frequency_in_mhz': 'float',
            'cpu_implementation': 'str',
            'cores_per_socket': 'int',
            'total_sockets': 'int',
            'threads_per_socket': 'int',
            'is_hyper_threading_enabled': 'bool',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)',
            'enterprise_manager_identifier': 'str',
            'enterprise_manager_bridge_id': 'str',
            'exadata_details': 'ExadataDetails'
        }

        self.attribute_map = {
            'host_insight_id': 'hostInsightId',
            'entity_source': 'entitySource',
            'compartment_id': 'compartmentId',
            'host_name': 'hostName',
            'platform_type': 'platformType',
            'platform_version': 'platformVersion',
            'platform_vendor': 'platformVendor',
            'total_cpus': 'totalCpus',
            'total_memory_in_gbs': 'totalMemoryInGBs',
            'cpu_architecture': 'cpuArchitecture',
            'cpu_cache_in_mbs': 'cpuCacheInMBs',
            'cpu_vendor': 'cpuVendor',
            'cpu_frequency_in_mhz': 'cpuFrequencyInMhz',
            'cpu_implementation': 'cpuImplementation',
            'cores_per_socket': 'coresPerSocket',
            'total_sockets': 'totalSockets',
            'threads_per_socket': 'threadsPerSocket',
            'is_hyper_threading_enabled': 'isHyperThreadingEnabled',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags',
            'enterprise_manager_identifier': 'enterpriseManagerIdentifier',
            'enterprise_manager_bridge_id': 'enterpriseManagerBridgeId',
            'exadata_details': 'exadataDetails'
        }

        self._host_insight_id = None
        self._entity_source = None
        self._compartment_id = None
        self._host_name = None
        self._platform_type = None
        self._platform_version = None
        self._platform_vendor = None
        self._total_cpus = None
        self._total_memory_in_gbs = None
        self._cpu_architecture = None
        self._cpu_cache_in_mbs = None
        self._cpu_vendor = None
        self._cpu_frequency_in_mhz = None
        self._cpu_implementation = None
        self._cores_per_socket = None
        self._total_sockets = None
        self._threads_per_socket = None
        self._is_hyper_threading_enabled = None
        self._defined_tags = None
        self._freeform_tags = None
        self._enterprise_manager_identifier = None
        self._enterprise_manager_bridge_id = None
        self._exadata_details = None
        self._entity_source = 'EM_MANAGED_EXTERNAL_HOST'

    @property
    def enterprise_manager_identifier(self):
        """
        **[Required]** Gets the enterprise_manager_identifier of this EmManagedExternalHostConfigurationSummary.
        Enterprise Manager Unique Identifier


        :return: The enterprise_manager_identifier of this EmManagedExternalHostConfigurationSummary.
        :rtype: str
        """
        return self._enterprise_manager_identifier

    @enterprise_manager_identifier.setter
    def enterprise_manager_identifier(self, enterprise_manager_identifier):
        """
        Sets the enterprise_manager_identifier of this EmManagedExternalHostConfigurationSummary.
        Enterprise Manager Unique Identifier


        :param enterprise_manager_identifier: The enterprise_manager_identifier of this EmManagedExternalHostConfigurationSummary.
        :type: str
        """
        self._enterprise_manager_identifier = enterprise_manager_identifier

    @property
    def enterprise_manager_bridge_id(self):
        """
        **[Required]** Gets the enterprise_manager_bridge_id of this EmManagedExternalHostConfigurationSummary.
        OPSI Enterprise Manager Bridge OCID


        :return: The enterprise_manager_bridge_id of this EmManagedExternalHostConfigurationSummary.
        :rtype: str
        """
        return self._enterprise_manager_bridge_id

    @enterprise_manager_bridge_id.setter
    def enterprise_manager_bridge_id(self, enterprise_manager_bridge_id):
        """
        Sets the enterprise_manager_bridge_id of this EmManagedExternalHostConfigurationSummary.
        OPSI Enterprise Manager Bridge OCID


        :param enterprise_manager_bridge_id: The enterprise_manager_bridge_id of this EmManagedExternalHostConfigurationSummary.
        :type: str
        """
        self._enterprise_manager_bridge_id = enterprise_manager_bridge_id

    @property
    def exadata_details(self):
        """
        **[Required]** Gets the exadata_details of this EmManagedExternalHostConfigurationSummary.

        :return: The exadata_details of this EmManagedExternalHostConfigurationSummary.
        :rtype: oci.opsi.models.ExadataDetails
        """
        return self._exadata_details

    @exadata_details.setter
    def exadata_details(self, exadata_details):
        """
        Sets the exadata_details of this EmManagedExternalHostConfigurationSummary.

        :param exadata_details: The exadata_details of this EmManagedExternalHostConfigurationSummary.
        :type: oci.opsi.models.ExadataDetails
        """
        self._exadata_details = exadata_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LaunchInstanceShapeConfigDetails(object):
    """
    The shape configuration requested for the instance.

    If the parameter is provided, the instance is created with the resources that you specify. If some
    properties are missing or the entire parameter is not provided, the instance is created
    with the default configuration values for the `shape` that you specify.

    Each shape only supports certain configurable values. If the values that you provide are not valid for the
    specified `shape`, an error is returned.
    """

    #: A constant which can be used with the baseline_ocpu_utilization property of a LaunchInstanceShapeConfigDetails.
    #: This constant has a value of "BASELINE_1_8"
    BASELINE_OCPU_UTILIZATION_BASELINE_1_8 = "BASELINE_1_8"

    #: A constant which can be used with the baseline_ocpu_utilization property of a LaunchInstanceShapeConfigDetails.
    #: This constant has a value of "BASELINE_1_2"
    BASELINE_OCPU_UTILIZATION_BASELINE_1_2 = "BASELINE_1_2"

    #: A constant which can be used with the baseline_ocpu_utilization property of a LaunchInstanceShapeConfigDetails.
    #: This constant has a value of "BASELINE_1_1"
    BASELINE_OCPU_UTILIZATION_BASELINE_1_1 = "BASELINE_1_1"

    def __init__(self, **kwargs):
        """
        Initializes a new LaunchInstanceShapeConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ocpus:
            The value to assign to the ocpus property of this LaunchInstanceShapeConfigDetails.
        :type ocpus: float

        :param memory_in_gbs:
            The value to assign to the memory_in_gbs property of this LaunchInstanceShapeConfigDetails.
        :type memory_in_gbs: float

        :param baseline_ocpu_utilization:
            The value to assign to the baseline_ocpu_utilization property of this LaunchInstanceShapeConfigDetails.
            Allowed values for this property are: "BASELINE_1_8", "BASELINE_1_2", "BASELINE_1_1"
        :type baseline_ocpu_utilization: str

        :param nvmes:
            The value to assign to the nvmes property of this LaunchInstanceShapeConfigDetails.
        :type nvmes: int

        """
        self.swagger_types = {
            'ocpus': 'float',
            'memory_in_gbs': 'float',
            'baseline_ocpu_utilization': 'str',
            'nvmes': 'int'
        }

        self.attribute_map = {
            'ocpus': 'ocpus',
            'memory_in_gbs': 'memoryInGBs',
            'baseline_ocpu_utilization': 'baselineOcpuUtilization',
            'nvmes': 'nvmes'
        }

        self._ocpus = None
        self._memory_in_gbs = None
        self._baseline_ocpu_utilization = None
        self._nvmes = None

    @property
    def ocpus(self):
        """
        Gets the ocpus of this LaunchInstanceShapeConfigDetails.
        The total number of OCPUs available to the instance.


        :return: The ocpus of this LaunchInstanceShapeConfigDetails.
        :rtype: float
        """
        return self._ocpus

    @ocpus.setter
    def ocpus(self, ocpus):
        """
        Sets the ocpus of this LaunchInstanceShapeConfigDetails.
        The total number of OCPUs available to the instance.


        :param ocpus: The ocpus of this LaunchInstanceShapeConfigDetails.
        :type: float
        """
        self._ocpus = ocpus

    @property
    def memory_in_gbs(self):
        """
        Gets the memory_in_gbs of this LaunchInstanceShapeConfigDetails.
        The total amount of memory available to the instance, in gigabytes.


        :return: The memory_in_gbs of this LaunchInstanceShapeConfigDetails.
        :rtype: float
        """
        return self._memory_in_gbs

    @memory_in_gbs.setter
    def memory_in_gbs(self, memory_in_gbs):
        """
        Sets the memory_in_gbs of this LaunchInstanceShapeConfigDetails.
        The total amount of memory available to the instance, in gigabytes.


        :param memory_in_gbs: The memory_in_gbs of this LaunchInstanceShapeConfigDetails.
        :type: float
        """
        self._memory_in_gbs = memory_in_gbs

    @property
    def baseline_ocpu_utilization(self):
        """
        Gets the baseline_ocpu_utilization of this LaunchInstanceShapeConfigDetails.
        The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a
        non-burstable instance, or explicitly specify non-burstable with `BASELINE_1_1`.

        The following values are supported:
        - `BASELINE_1_8` - baseline usage is 1/8 of an OCPU.
        - `BASELINE_1_2` - baseline usage is 1/2 of an OCPU.
        - `BASELINE_1_1` - baseline usage is an entire OCPU. This represents a non-burstable instance.

        Allowed values for this property are: "BASELINE_1_8", "BASELINE_1_2", "BASELINE_1_1"


        :return: The baseline_ocpu_utilization of this LaunchInstanceShapeConfigDetails.
        :rtype: str
        """
        return self._baseline_ocpu_utilization

    @baseline_ocpu_utilization.setter
    def baseline_ocpu_utilization(self, baseline_ocpu_utilization):
        """
        Sets the baseline_ocpu_utilization of this LaunchInstanceShapeConfigDetails.
        The baseline OCPU utilization for a subcore burstable VM instance. Leave this attribute blank for a
        non-burstable instance, or explicitly specify non-burstable with `BASELINE_1_1`.

        The following values are supported:
        - `BASELINE_1_8` - baseline usage is 1/8 of an OCPU.
        - `BASELINE_1_2` - baseline usage is 1/2 of an OCPU.
        - `BASELINE_1_1` - baseline usage is an entire OCPU. This represents a non-burstable instance.


        :param baseline_ocpu_utilization: The baseline_ocpu_utilization of this LaunchInstanceShapeConfigDetails.
        :type: str
        """
        allowed_values = ["BASELINE_1_8", "BASELINE_1_2", "BASELINE_1_1"]
        if not value_allowed_none_or_none_sentinel(baseline_ocpu_utilization, allowed_values):
            raise ValueError(
                "Invalid value for `baseline_ocpu_utilization`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._baseline_ocpu_utilization = baseline_ocpu_utilization

    @property
    def nvmes(self):
        """
        Gets the nvmes of this LaunchInstanceShapeConfigDetails.
        The number of NVMe drives to be used for storage. A single drive has 6.8 TB available.


        :return: The nvmes of this LaunchInstanceShapeConfigDetails.
        :rtype: int
        """
        return self._nvmes

    @nvmes.setter
    def nvmes(self, nvmes):
        """
        Sets the nvmes of this LaunchInstanceShapeConfigDetails.
        The number of NVMe drives to be used for storage. A single drive has 6.8 TB available.


        :param nvmes: The nvmes of this LaunchInstanceShapeConfigDetails.
        :type: int
        """
        self._nvmes = nvmes

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateMacsecProperties(object):
    """
    Properties used to configure MACsec (if capable).
    """

    #: A constant which can be used with the state property of a CreateMacsecProperties.
    #: This constant has a value of "ENABLED"
    STATE_ENABLED = "ENABLED"

    #: A constant which can be used with the state property of a CreateMacsecProperties.
    #: This constant has a value of "DISABLED"
    STATE_DISABLED = "DISABLED"

    #: A constant which can be used with the encryption_cipher property of a CreateMacsecProperties.
    #: This constant has a value of "AES128_GCM"
    ENCRYPTION_CIPHER_AES128_GCM = "AES128_GCM"

    #: A constant which can be used with the encryption_cipher property of a CreateMacsecProperties.
    #: This constant has a value of "AES128_GCM_XPN"
    ENCRYPTION_CIPHER_AES128_GCM_XPN = "AES128_GCM_XPN"

    #: A constant which can be used with the encryption_cipher property of a CreateMacsecProperties.
    #: This constant has a value of "AES256_GCM"
    ENCRYPTION_CIPHER_AES256_GCM = "AES256_GCM"

    #: A constant which can be used with the encryption_cipher property of a CreateMacsecProperties.
    #: This constant has a value of "AES256_GCM_XPN"
    ENCRYPTION_CIPHER_AES256_GCM_XPN = "AES256_GCM_XPN"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateMacsecProperties object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param state:
            The value to assign to the state property of this CreateMacsecProperties.
            Allowed values for this property are: "ENABLED", "DISABLED"
        :type state: str

        :param primary_key:
            The value to assign to the primary_key property of this CreateMacsecProperties.
        :type primary_key: oci.core.models.CreateMacsecKey

        :param encryption_cipher:
            The value to assign to the encryption_cipher property of this CreateMacsecProperties.
            Allowed values for this property are: "AES128_GCM", "AES128_GCM_XPN", "AES256_GCM", "AES256_GCM_XPN"
        :type encryption_cipher: str

        """
        self.swagger_types = {
            'state': 'str',
            'primary_key': 'CreateMacsecKey',
            'encryption_cipher': 'str'
        }

        self.attribute_map = {
            'state': 'state',
            'primary_key': 'primaryKey',
            'encryption_cipher': 'encryptionCipher'
        }

        self._state = None
        self._primary_key = None
        self._encryption_cipher = None

    @property
    def state(self):
        """
        **[Required]** Gets the state of this CreateMacsecProperties.
        Indicates whether or not MACsec is enabled.

        Allowed values for this property are: "ENABLED", "DISABLED"


        :return: The state of this CreateMacsecProperties.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this CreateMacsecProperties.
        Indicates whether or not MACsec is enabled.


        :param state: The state of this CreateMacsecProperties.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            raise ValueError(
                "Invalid value for `state`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def primary_key(self):
        """
        Gets the primary_key of this CreateMacsecProperties.

        :return: The primary_key of this CreateMacsecProperties.
        :rtype: oci.core.models.CreateMacsecKey
        """
        return self._primary_key

    @primary_key.setter
    def primary_key(self, primary_key):
        """
        Sets the primary_key of this CreateMacsecProperties.

        :param primary_key: The primary_key of this CreateMacsecProperties.
        :type: oci.core.models.CreateMacsecKey
        """
        self._primary_key = primary_key

    @property
    def encryption_cipher(self):
        """
        Gets the encryption_cipher of this CreateMacsecProperties.
        Type of encryption cipher suite to use for the MACsec connection.

        Allowed values for this property are: "AES128_GCM", "AES128_GCM_XPN", "AES256_GCM", "AES256_GCM_XPN"


        :return: The encryption_cipher of this CreateMacsecProperties.
        :rtype: str
        """
        return self._encryption_cipher

    @encryption_cipher.setter
    def encryption_cipher(self, encryption_cipher):
        """
        Sets the encryption_cipher of this CreateMacsecProperties.
        Type of encryption cipher suite to use for the MACsec connection.


        :param encryption_cipher: The encryption_cipher of this CreateMacsecProperties.
        :type: str
        """
        allowed_values = ["AES128_GCM", "AES128_GCM_XPN", "AES256_GCM", "AES256_GCM_XPN"]
        if not value_allowed_none_or_none_sentinel(encryption_cipher, allowed_values):
            raise ValueError(
                "Invalid value for `encryption_cipher`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._encryption_cipher = encryption_cipher

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InvoicingLocation(object):
    """
    Address location.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InvoicingLocation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param address1:
            The value to assign to the address1 property of this InvoicingLocation.
        :type address1: str

        :param address2:
            The value to assign to the address2 property of this InvoicingLocation.
        :type address2: str

        :param postal_code:
            The value to assign to the postal_code property of this InvoicingLocation.
        :type postal_code: str

        :param city:
            The value to assign to the city property of this InvoicingLocation.
        :type city: str

        :param country:
            The value to assign to the country property of this InvoicingLocation.
        :type country: str

        :param region:
            The value to assign to the region property of this InvoicingLocation.
        :type region: str

        :param tca_location_id:
            The value to assign to the tca_location_id property of this InvoicingLocation.
        :type tca_location_id: int

        """
        self.swagger_types = {
            'address1': 'str',
            'address2': 'str',
            'postal_code': 'str',
            'city': 'str',
            'country': 'str',
            'region': 'str',
            'tca_location_id': 'int'
        }

        self.attribute_map = {
            'address1': 'address1',
            'address2': 'address2',
            'postal_code': 'postalCode',
            'city': 'city',
            'country': 'country',
            'region': 'region',
            'tca_location_id': 'tcaLocationId'
        }

        self._address1 = None
        self._address2 = None
        self._postal_code = None
        self._city = None
        self._country = None
        self._region = None
        self._tca_location_id = None

    @property
    def address1(self):
        """
        Gets the address1 of this InvoicingLocation.
        Address first line.


        :return: The address1 of this InvoicingLocation.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this InvoicingLocation.
        Address first line.


        :param address1: The address1 of this InvoicingLocation.
        :type: str
        """
        self._address1 = address1

    @property
    def address2(self):
        """
        Gets the address2 of this InvoicingLocation.
        Address second line.


        :return: The address2 of this InvoicingLocation.
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """
        Sets the address2 of this InvoicingLocation.
        Address second line.


        :param address2: The address2 of this InvoicingLocation.
        :type: str
        """
        self._address2 = address2

    @property
    def postal_code(self):
        """
        Gets the postal_code of this InvoicingLocation.
        Postal code.


        :return: The postal_code of this InvoicingLocation.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this InvoicingLocation.
        Postal code.


        :param postal_code: The postal_code of this InvoicingLocation.
        :type: str
        """
        self._postal_code = postal_code

    @property
    def city(self):
        """
        Gets the city of this InvoicingLocation.
        City.


        :return: The city of this InvoicingLocation.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this InvoicingLocation.
        City.


        :param city: The city of this InvoicingLocation.
        :type: str
        """
        self._city = city

    @property
    def country(self):
        """
        Gets the country of this InvoicingLocation.
        Country.


        :return: The country of this InvoicingLocation.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this InvoicingLocation.
        Country.


        :param country: The country of this InvoicingLocation.
        :type: str
        """
        self._country = country

    @property
    def region(self):
        """
        Gets the region of this InvoicingLocation.
        Region.


        :return: The region of this InvoicingLocation.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this InvoicingLocation.
        Region.


        :param region: The region of this InvoicingLocation.
        :type: str
        """
        self._region = region

    @property
    def tca_location_id(self):
        """
        Gets the tca_location_id of this InvoicingLocation.
        TCA Location identifier.


        :return: The tca_location_id of this InvoicingLocation.
        :rtype: int
        """
        return self._tca_location_id

    @tca_location_id.setter
    def tca_location_id(self, tca_location_id):
        """
        Sets the tca_location_id of this InvoicingLocation.
        TCA Location identifier.


        :param tca_location_id: The tca_location_id of this InvoicingLocation.
        :type: int
        """
        self._tca_location_id = tca_location_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CommonPrincipal(object):
    """
    CommonPrincipal model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CommonPrincipal object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tenant:
            The value to assign to the tenant property of this CommonPrincipal.
        :type tenant: oci.identity_data_plane.models.Tenant

        :param user:
            The value to assign to the user property of this CommonPrincipal.
        :type user: oci.identity_data_plane.models.User

        """
        self.swagger_types = {
            'tenant': 'Tenant',
            'user': 'User'
        }

        self.attribute_map = {
            'tenant': 'tenant',
            'user': 'user'
        }

        self._tenant = None
        self._user = None

    @property
    def tenant(self):
        """
        **[Required]** Gets the tenant of this CommonPrincipal.
        The tenant.


        :return: The tenant of this CommonPrincipal.
        :rtype: oci.identity_data_plane.models.Tenant
        """
        return self._tenant

    @tenant.setter
    def tenant(self, tenant):
        """
        Sets the tenant of this CommonPrincipal.
        The tenant.


        :param tenant: The tenant of this CommonPrincipal.
        :type: oci.identity_data_plane.models.Tenant
        """
        self._tenant = tenant

    @property
    def user(self):
        """
        **[Required]** Gets the user of this CommonPrincipal.
        The user.


        :return: The user of this CommonPrincipal.
        :rtype: oci.identity_data_plane.models.User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this CommonPrincipal.
        The user.


        :param user: The user of this CommonPrincipal.
        :type: oci.identity_data_plane.models.User
        """
        self._user = user

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateAwsS3Details(object):
    """
    AWS S3 bucket details used for source Connection resources with RDS_ORACLE type.
    Only supported for source Connection resources with RDS_ORACLE type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateAwsS3Details object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this UpdateAwsS3Details.
        :type name: str

        :param region:
            The value to assign to the region property of this UpdateAwsS3Details.
        :type region: str

        :param access_key_id:
            The value to assign to the access_key_id property of this UpdateAwsS3Details.
        :type access_key_id: str

        :param secret_access_key:
            The value to assign to the secret_access_key property of this UpdateAwsS3Details.
        :type secret_access_key: str

        """
        self.swagger_types = {
            'name': 'str',
            'region': 'str',
            'access_key_id': 'str',
            'secret_access_key': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'region': 'region',
            'access_key_id': 'accessKeyId',
            'secret_access_key': 'secretAccessKey'
        }

        self._name = None
        self._region = None
        self._access_key_id = None
        self._secret_access_key = None

    @property
    def name(self):
        """
        Gets the name of this UpdateAwsS3Details.
        S3 bucket name.


        :return: The name of this UpdateAwsS3Details.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateAwsS3Details.
        S3 bucket name.


        :param name: The name of this UpdateAwsS3Details.
        :type: str
        """
        self._name = name

    @property
    def region(self):
        """
        Gets the region of this UpdateAwsS3Details.
        AWS region code where the S3 bucket is located.
        Region code should match the documented available regions:
        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-regions-availability-zones.html#concepts-available-regions


        :return: The region of this UpdateAwsS3Details.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this UpdateAwsS3Details.
        AWS region code where the S3 bucket is located.
        Region code should match the documented available regions:
        https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-regions-availability-zones.html#concepts-available-regions


        :param region: The region of this UpdateAwsS3Details.
        :type: str
        """
        self._region = region

    @property
    def access_key_id(self):
        """
        Gets the access_key_id of this UpdateAwsS3Details.
        AWS access key credentials identifier
        Details: https://docs.aws.amazon.com/general/latest/gr/aws-sec-cred-types.html#access-keys-and-secret-access-keys


        :return: The access_key_id of this UpdateAwsS3Details.
        :rtype: str
        """
        return self._access_key_id

    @access_key_id.setter
    def access_key_id(self, access_key_id):
        """
        Sets the access_key_id of this UpdateAwsS3Details.
        AWS access key credentials identifier
        Details: https://docs.aws.amazon.com/general/latest/gr/aws-sec-cred-types.html#access-keys-and-secret-access-keys


        :param access_key_id: The access_key_id of this UpdateAwsS3Details.
        :type: str
        """
        self._access_key_id = access_key_id

    @property
    def secret_access_key(self):
        """
        Gets the secret_access_key of this UpdateAwsS3Details.
        AWS secret access key credentials
        Details: https://docs.aws.amazon.com/general/latest/gr/aws-sec-cred-types.html#access-keys-and-secret-access-keys


        :return: The secret_access_key of this UpdateAwsS3Details.
        :rtype: str
        """
        return self._secret_access_key

    @secret_access_key.setter
    def secret_access_key(self, secret_access_key):
        """
        Sets the secret_access_key of this UpdateAwsS3Details.
        AWS secret access key credentials
        Details: https://docs.aws.amazon.com/general/latest/gr/aws-sec-cred-types.html#access-keys-and-secret-access-keys


        :param secret_access_key: The secret_access_key of this UpdateAwsS3Details.
        :type: str
        """
        self._secret_access_key = secret_access_key

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateFolderDetails(object):
    """
    The properties used in folder update operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateFolderDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this UpdateFolderDetails.
        :type key: str

        :param model_type:
            The value to assign to the model_type property of this UpdateFolderDetails.
        :type model_type: str

        :param model_version:
            The value to assign to the model_version property of this UpdateFolderDetails.
        :type model_version: str

        :param name:
            The value to assign to the name property of this UpdateFolderDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this UpdateFolderDetails.
        :type description: str

        :param category_name:
            The value to assign to the category_name property of this UpdateFolderDetails.
        :type category_name: str

        :param object_status:
            The value to assign to the object_status property of this UpdateFolderDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this UpdateFolderDetails.
        :type identifier: str

        :param parent_ref:
            The value to assign to the parent_ref property of this UpdateFolderDetails.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param object_version:
            The value to assign to the object_version property of this UpdateFolderDetails.
        :type object_version: int

        :param registry_metadata:
            The value to assign to the registry_metadata property of this UpdateFolderDetails.
        :type registry_metadata: oci.data_integration.models.RegistryMetadata

        """
        self.swagger_types = {
            'key': 'str',
            'model_type': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'category_name': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'parent_ref': 'ParentReference',
            'object_version': 'int',
            'registry_metadata': 'RegistryMetadata'
        }

        self.attribute_map = {
            'key': 'key',
            'model_type': 'modelType',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'category_name': 'categoryName',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'parent_ref': 'parentRef',
            'object_version': 'objectVersion',
            'registry_metadata': 'registryMetadata'
        }

        self._key = None
        self._model_type = None
        self._model_version = None
        self._name = None
        self._description = None
        self._category_name = None
        self._object_status = None
        self._identifier = None
        self._parent_ref = None
        self._object_version = None
        self._registry_metadata = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this UpdateFolderDetails.
        Generated key that can be used in API calls to identify folder.


        :return: The key of this UpdateFolderDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this UpdateFolderDetails.
        Generated key that can be used in API calls to identify folder.


        :param key: The key of this UpdateFolderDetails.
        :type: str
        """
        self._key = key

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this UpdateFolderDetails.
        The type of the object.


        :return: The model_type of this UpdateFolderDetails.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this UpdateFolderDetails.
        The type of the object.


        :param model_type: The model_type of this UpdateFolderDetails.
        :type: str
        """
        self._model_type = model_type

    @property
    def model_version(self):
        """
        Gets the model_version of this UpdateFolderDetails.
        The model version of an object.


        :return: The model_version of this UpdateFolderDetails.
        :rtype: str
        """
        return self._model_version

    @model_version.setter
    def model_version(self, model_version):
        """
        Sets the model_version of this UpdateFolderDetails.
        The model version of an object.


        :param model_version: The model_version of this UpdateFolderDetails.
        :type: str
        """
        self._model_version = model_version

    @property
    def name(self):
        """
        Gets the name of this UpdateFolderDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :return: The name of this UpdateFolderDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this UpdateFolderDetails.
        Free form text without any restriction on permitted characters. Name can have letters, numbers, and special characters. The value is editable and is restricted to 1000 characters.


        :param name: The name of this UpdateFolderDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this UpdateFolderDetails.
        A user defined description for the folder.


        :return: The description of this UpdateFolderDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateFolderDetails.
        A user defined description for the folder.


        :param description: The description of this UpdateFolderDetails.
        :type: str
        """
        self._description = description

    @property
    def category_name(self):
        """
        Gets the category_name of this UpdateFolderDetails.
        The category name.


        :return: The category_name of this UpdateFolderDetails.
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """
        Sets the category_name of this UpdateFolderDetails.
        The category name.


        :param category_name: The category_name of this UpdateFolderDetails.
        :type: str
        """
        self._category_name = category_name

    @property
    def object_status(self):
        """
        Gets the object_status of this UpdateFolderDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :return: The object_status of this UpdateFolderDetails.
        :rtype: int
        """
        return self._object_status

    @object_status.setter
    def object_status(self, object_status):
        """
        Sets the object_status of this UpdateFolderDetails.
        The status of an object that can be set to value 1 for shallow references across objects, other values reserved.


        :param object_status: The object_status of this UpdateFolderDetails.
        :type: int
        """
        self._object_status = object_status

    @property
    def identifier(self):
        """
        Gets the identifier of this UpdateFolderDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :return: The identifier of this UpdateFolderDetails.
        :rtype: str
        """
        return self._identifier

    @identifier.setter
    def identifier(self, identifier):
        """
        Sets the identifier of this UpdateFolderDetails.
        Value can only contain upper case letters, underscore, and numbers. It should begin with upper case letter or underscore. The value can be modified.


        :param identifier: The identifier of this UpdateFolderDetails.
        :type: str
        """
        self._identifier = identifier

    @property
    def parent_ref(self):
        """
        Gets the parent_ref of this UpdateFolderDetails.

        :return: The parent_ref of this UpdateFolderDetails.
        :rtype: oci.data_integration.models.ParentReference
        """
        return self._parent_ref

    @parent_ref.setter
    def parent_ref(self, parent_ref):
        """
        Sets the parent_ref of this UpdateFolderDetails.

        :param parent_ref: The parent_ref of this UpdateFolderDetails.
        :type: oci.data_integration.models.ParentReference
        """
        self._parent_ref = parent_ref

    @property
    def object_version(self):
        """
        **[Required]** Gets the object_version of this UpdateFolderDetails.
        The version of the object that is used to track changes in the object instance.


        :return: The object_version of this UpdateFolderDetails.
        :rtype: int
        """
        return self._object_version

    @object_version.setter
    def object_version(self, object_version):
        """
        Sets the object_version of this UpdateFolderDetails.
        The version of the object that is used to track changes in the object instance.


        :param object_version: The object_version of this UpdateFolderDetails.
        :type: int
        """
        self._object_version = object_version

    @property
    def registry_metadata(self):
        """
        Gets the registry_metadata of this UpdateFolderDetails.

        :return: The registry_metadata of this UpdateFolderDetails.
        :rtype: oci.data_integration.models.RegistryMetadata
        """
        return self._registry_metadata

    @registry_metadata.setter
    def registry_metadata(self, registry_metadata):
        """
        Sets the registry_metadata of this UpdateFolderDetails.

        :param registry_metadata: The registry_metadata of this UpdateFolderDetails.
        :type: oci.data_integration.models.RegistryMetadata
        """
        self._registry_metadata = registry_metadata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AllowedIkeIPSecParameters(object):
    """
    Lists the current allowed and default IPSec tunnel parameters.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AllowedIkeIPSecParameters object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param allowed_phase_one_parameters:
            The value to assign to the allowed_phase_one_parameters property of this AllowedIkeIPSecParameters.
        :type allowed_phase_one_parameters: oci.core.models.AllowedPhaseOneParameters

        :param allowed_phase_two_parameters:
            The value to assign to the allowed_phase_two_parameters property of this AllowedIkeIPSecParameters.
        :type allowed_phase_two_parameters: oci.core.models.AllowedPhaseTwoParameters

        :param default_phase_one_parameters:
            The value to assign to the default_phase_one_parameters property of this AllowedIkeIPSecParameters.
        :type default_phase_one_parameters: oci.core.models.DefaultPhaseOneParameters

        :param default_phase_two_parameters:
            The value to assign to the default_phase_two_parameters property of this AllowedIkeIPSecParameters.
        :type default_phase_two_parameters: oci.core.models.DefaultPhaseTwoParameters

        """
        self.swagger_types = {
            'allowed_phase_one_parameters': 'AllowedPhaseOneParameters',
            'allowed_phase_two_parameters': 'AllowedPhaseTwoParameters',
            'default_phase_one_parameters': 'DefaultPhaseOneParameters',
            'default_phase_two_parameters': 'DefaultPhaseTwoParameters'
        }

        self.attribute_map = {
            'allowed_phase_one_parameters': 'allowedPhaseOneParameters',
            'allowed_phase_two_parameters': 'allowedPhaseTwoParameters',
            'default_phase_one_parameters': 'defaultPhaseOneParameters',
            'default_phase_two_parameters': 'defaultPhaseTwoParameters'
        }

        self._allowed_phase_one_parameters = None
        self._allowed_phase_two_parameters = None
        self._default_phase_one_parameters = None
        self._default_phase_two_parameters = None

    @property
    def allowed_phase_one_parameters(self):
        """
        **[Required]** Gets the allowed_phase_one_parameters of this AllowedIkeIPSecParameters.

        :return: The allowed_phase_one_parameters of this AllowedIkeIPSecParameters.
        :rtype: oci.core.models.AllowedPhaseOneParameters
        """
        return self._allowed_phase_one_parameters

    @allowed_phase_one_parameters.setter
    def allowed_phase_one_parameters(self, allowed_phase_one_parameters):
        """
        Sets the allowed_phase_one_parameters of this AllowedIkeIPSecParameters.

        :param allowed_phase_one_parameters: The allowed_phase_one_parameters of this AllowedIkeIPSecParameters.
        :type: oci.core.models.AllowedPhaseOneParameters
        """
        self._allowed_phase_one_parameters = allowed_phase_one_parameters

    @property
    def allowed_phase_two_parameters(self):
        """
        **[Required]** Gets the allowed_phase_two_parameters of this AllowedIkeIPSecParameters.

        :return: The allowed_phase_two_parameters of this AllowedIkeIPSecParameters.
        :rtype: oci.core.models.AllowedPhaseTwoParameters
        """
        return self._allowed_phase_two_parameters

    @allowed_phase_two_parameters.setter
    def allowed_phase_two_parameters(self, allowed_phase_two_parameters):
        """
        Sets the allowed_phase_two_parameters of this AllowedIkeIPSecParameters.

        :param allowed_phase_two_parameters: The allowed_phase_two_parameters of this AllowedIkeIPSecParameters.
        :type: oci.core.models.AllowedPhaseTwoParameters
        """
        self._allowed_phase_two_parameters = allowed_phase_two_parameters

    @property
    def default_phase_one_parameters(self):
        """
        **[Required]** Gets the default_phase_one_parameters of this AllowedIkeIPSecParameters.

        :return: The default_phase_one_parameters of this AllowedIkeIPSecParameters.
        :rtype: oci.core.models.DefaultPhaseOneParameters
        """
        return self._default_phase_one_parameters

    @default_phase_one_parameters.setter
    def default_phase_one_parameters(self, default_phase_one_parameters):
        """
        Sets the default_phase_one_parameters of this AllowedIkeIPSecParameters.

        :param default_phase_one_parameters: The default_phase_one_parameters of this AllowedIkeIPSecParameters.
        :type: oci.core.models.DefaultPhaseOneParameters
        """
        self._default_phase_one_parameters = default_phase_one_parameters

    @property
    def default_phase_two_parameters(self):
        """
        **[Required]** Gets the default_phase_two_parameters of this AllowedIkeIPSecParameters.

        :return: The default_phase_two_parameters of this AllowedIkeIPSecParameters.
        :rtype: oci.core.models.DefaultPhaseTwoParameters
        """
        return self._default_phase_two_parameters

    @default_phase_two_parameters.setter
    def default_phase_two_parameters(self, default_phase_two_parameters):
        """
        Sets the default_phase_two_parameters of this AllowedIkeIPSecParameters.

        :param default_phase_two_parameters: The default_phase_two_parameters of this AllowedIkeIPSecParameters.
        :type: oci.core.models.DefaultPhaseTwoParameters
        """
        self._default_phase_two_parameters = default_phase_two_parameters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateModuleDetails(object):
    """
    A description of a module and its stream
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateModuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param module_name:
            The value to assign to the module_name property of this UpdateModuleDetails.
        :type module_name: str

        :param streams:
            The value to assign to the streams property of this UpdateModuleDetails.
        :type streams: list[oci.os_management.models.UpdateModuleStreamDetails]

        """
        self.swagger_types = {
            'module_name': 'str',
            'streams': 'list[UpdateModuleStreamDetails]'
        }

        self.attribute_map = {
            'module_name': 'moduleName',
            'streams': 'streams'
        }

        self._module_name = None
        self._streams = None

    @property
    def module_name(self):
        """
        **[Required]** Gets the module_name of this UpdateModuleDetails.
        The name of a module


        :return: The module_name of this UpdateModuleDetails.
        :rtype: str
        """
        return self._module_name

    @module_name.setter
    def module_name(self, module_name):
        """
        Sets the module_name of this UpdateModuleDetails.
        The name of a module


        :param module_name: The module_name of this UpdateModuleDetails.
        :type: str
        """
        self._module_name = module_name

    @property
    def streams(self):
        """
        Gets the streams of this UpdateModuleDetails.
        The streams of the module


        :return: The streams of this UpdateModuleDetails.
        :rtype: list[oci.os_management.models.UpdateModuleStreamDetails]
        """
        return self._streams

    @streams.setter
    def streams(self, streams):
        """
        Sets the streams of this UpdateModuleDetails.
        The streams of the module


        :param streams: The streams of this UpdateModuleDetails.
        :type: list[oci.os_management.models.UpdateModuleStreamDetails]
        """
        self._streams = streams

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SensitiveColumn(object):
    """
    A sensitive column is a resource corresponding to a database column that is considered sensitive.
    It's a subresource of sensitive data model resource and is always associated with a sensitive data model.
    Note that referential relationships are also managed as part of sensitive columns.
    """

    #: A constant which can be used with the lifecycle_state property of a SensitiveColumn.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SensitiveColumn.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SensitiveColumn.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a SensitiveColumn.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SensitiveColumn.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the object_type property of a SensitiveColumn.
    #: This constant has a value of "TABLE"
    OBJECT_TYPE_TABLE = "TABLE"

    #: A constant which can be used with the object_type property of a SensitiveColumn.
    #: This constant has a value of "EDITIONING_VIEW"
    OBJECT_TYPE_EDITIONING_VIEW = "EDITIONING_VIEW"

    #: A constant which can be used with the status property of a SensitiveColumn.
    #: This constant has a value of "VALID"
    STATUS_VALID = "VALID"

    #: A constant which can be used with the status property of a SensitiveColumn.
    #: This constant has a value of "INVALID"
    STATUS_INVALID = "INVALID"

    #: A constant which can be used with the source property of a SensitiveColumn.
    #: This constant has a value of "MANUAL"
    SOURCE_MANUAL = "MANUAL"

    #: A constant which can be used with the source property of a SensitiveColumn.
    #: This constant has a value of "DISCOVERY"
    SOURCE_DISCOVERY = "DISCOVERY"

    #: A constant which can be used with the relation_type property of a SensitiveColumn.
    #: This constant has a value of "NONE"
    RELATION_TYPE_NONE = "NONE"

    #: A constant which can be used with the relation_type property of a SensitiveColumn.
    #: This constant has a value of "APP_DEFINED"
    RELATION_TYPE_APP_DEFINED = "APP_DEFINED"

    #: A constant which can be used with the relation_type property of a SensitiveColumn.
    #: This constant has a value of "DB_DEFINED"
    RELATION_TYPE_DB_DEFINED = "DB_DEFINED"

    def __init__(self, **kwargs):
        """
        Initializes a new SensitiveColumn object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this SensitiveColumn.
        :type key: str

        :param sensitive_data_model_id:
            The value to assign to the sensitive_data_model_id property of this SensitiveColumn.
        :type sensitive_data_model_id: str

        :param time_created:
            The value to assign to the time_created property of this SensitiveColumn.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SensitiveColumn.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SensitiveColumn.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this SensitiveColumn.
        :type lifecycle_details: str

        :param app_name:
            The value to assign to the app_name property of this SensitiveColumn.
        :type app_name: str

        :param schema_name:
            The value to assign to the schema_name property of this SensitiveColumn.
        :type schema_name: str

        :param object_name:
            The value to assign to the object_name property of this SensitiveColumn.
        :type object_name: str

        :param column_name:
            The value to assign to the column_name property of this SensitiveColumn.
        :type column_name: str

        :param object_type:
            The value to assign to the object_type property of this SensitiveColumn.
            Allowed values for this property are: "TABLE", "EDITIONING_VIEW", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type object_type: str

        :param data_type:
            The value to assign to the data_type property of this SensitiveColumn.
        :type data_type: str

        :param status:
            The value to assign to the status property of this SensitiveColumn.
            Allowed values for this property are: "VALID", "INVALID", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param sensitive_type_id:
            The value to assign to the sensitive_type_id property of this SensitiveColumn.
        :type sensitive_type_id: str

        :param source:
            The value to assign to the source property of this SensitiveColumn.
            Allowed values for this property are: "MANUAL", "DISCOVERY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source: str

        :param parent_column_keys:
            The value to assign to the parent_column_keys property of this SensitiveColumn.
        :type parent_column_keys: list[str]

        :param relation_type:
            The value to assign to the relation_type property of this SensitiveColumn.
            Allowed values for this property are: "NONE", "APP_DEFINED", "DB_DEFINED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type relation_type: str

        :param estimated_data_value_count:
            The value to assign to the estimated_data_value_count property of this SensitiveColumn.
        :type estimated_data_value_count: int

        :param sample_data_values:
            The value to assign to the sample_data_values property of this SensitiveColumn.
        :type sample_data_values: list[str]

        :param app_defined_child_column_keys:
            The value to assign to the app_defined_child_column_keys property of this SensitiveColumn.
        :type app_defined_child_column_keys: list[str]

        :param db_defined_child_column_keys:
            The value to assign to the db_defined_child_column_keys property of this SensitiveColumn.
        :type db_defined_child_column_keys: list[str]

        :param column_groups:
            The value to assign to the column_groups property of this SensitiveColumn.
        :type column_groups: list[str]

        """
        self.swagger_types = {
            'key': 'str',
            'sensitive_data_model_id': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'app_name': 'str',
            'schema_name': 'str',
            'object_name': 'str',
            'column_name': 'str',
            'object_type': 'str',
            'data_type': 'str',
            'status': 'str',
            'sensitive_type_id': 'str',
            'source': 'str',
            'parent_column_keys': 'list[str]',
            'relation_type': 'str',
            'estimated_data_value_count': 'int',
            'sample_data_values': 'list[str]',
            'app_defined_child_column_keys': 'list[str]',
            'db_defined_child_column_keys': 'list[str]',
            'column_groups': 'list[str]'
        }

        self.attribute_map = {
            'key': 'key',
            'sensitive_data_model_id': 'sensitiveDataModelId',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'app_name': 'appName',
            'schema_name': 'schemaName',
            'object_name': 'objectName',
            'column_name': 'columnName',
            'object_type': 'objectType',
            'data_type': 'dataType',
            'status': 'status',
            'sensitive_type_id': 'sensitiveTypeId',
            'source': 'source',
            'parent_column_keys': 'parentColumnKeys',
            'relation_type': 'relationType',
            'estimated_data_value_count': 'estimatedDataValueCount',
            'sample_data_values': 'sampleDataValues',
            'app_defined_child_column_keys': 'appDefinedChildColumnKeys',
            'db_defined_child_column_keys': 'dbDefinedChildColumnKeys',
            'column_groups': 'columnGroups'
        }

        self._key = None
        self._sensitive_data_model_id = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._app_name = None
        self._schema_name = None
        self._object_name = None
        self._column_name = None
        self._object_type = None
        self._data_type = None
        self._status = None
        self._sensitive_type_id = None
        self._source = None
        self._parent_column_keys = None
        self._relation_type = None
        self._estimated_data_value_count = None
        self._sample_data_values = None
        self._app_defined_child_column_keys = None
        self._db_defined_child_column_keys = None
        self._column_groups = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this SensitiveColumn.
        The unique key that identifies the sensitive column. It's numeric and unique within a sensitive data model.


        :return: The key of this SensitiveColumn.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this SensitiveColumn.
        The unique key that identifies the sensitive column. It's numeric and unique within a sensitive data model.


        :param key: The key of this SensitiveColumn.
        :type: str
        """
        self._key = key

    @property
    def sensitive_data_model_id(self):
        """
        **[Required]** Gets the sensitive_data_model_id of this SensitiveColumn.
        The OCID of the sensitive data model that contains the sensitive column.


        :return: The sensitive_data_model_id of this SensitiveColumn.
        :rtype: str
        """
        return self._sensitive_data_model_id

    @sensitive_data_model_id.setter
    def sensitive_data_model_id(self, sensitive_data_model_id):
        """
        Sets the sensitive_data_model_id of this SensitiveColumn.
        The OCID of the sensitive data model that contains the sensitive column.


        :param sensitive_data_model_id: The sensitive_data_model_id of this SensitiveColumn.
        :type: str
        """
        self._sensitive_data_model_id = sensitive_data_model_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this SensitiveColumn.
        The date and time, in the format defined by `RFC3339`__,
        the sensitive column was created in the sensitive data model.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this SensitiveColumn.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SensitiveColumn.
        The date and time, in the format defined by `RFC3339`__,
        the sensitive column was created in the sensitive data model.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this SensitiveColumn.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this SensitiveColumn.
        The date and time, in the format defined by `RFC3339`__,
        the sensitive column was last updated in the sensitive data model.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this SensitiveColumn.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SensitiveColumn.
        The date and time, in the format defined by `RFC3339`__,
        the sensitive column was last updated in the sensitive data model.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this SensitiveColumn.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SensitiveColumn.
        The current state of the sensitive column.

        Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SensitiveColumn.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SensitiveColumn.
        The current state of the sensitive column.


        :param lifecycle_state: The lifecycle_state of this SensitiveColumn.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "UPDATING", "DELETING", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this SensitiveColumn.
        Details about the current state of the sensitive column.


        :return: The lifecycle_details of this SensitiveColumn.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this SensitiveColumn.
        Details about the current state of the sensitive column.


        :param lifecycle_details: The lifecycle_details of this SensitiveColumn.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def app_name(self):
        """
        **[Required]** Gets the app_name of this SensitiveColumn.
        The name of the application associated with the sensitive column. It's useful when the application name is
        different from the schema name. Otherwise, it can be ignored.


        :return: The app_name of this SensitiveColumn.
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """
        Sets the app_name of this SensitiveColumn.
        The name of the application associated with the sensitive column. It's useful when the application name is
        different from the schema name. Otherwise, it can be ignored.


        :param app_name: The app_name of this SensitiveColumn.
        :type: str
        """
        self._app_name = app_name

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this SensitiveColumn.
        The database schema that contains the sensitive column.


        :return: The schema_name of this SensitiveColumn.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this SensitiveColumn.
        The database schema that contains the sensitive column.


        :param schema_name: The schema_name of this SensitiveColumn.
        :type: str
        """
        self._schema_name = schema_name

    @property
    def object_name(self):
        """
        **[Required]** Gets the object_name of this SensitiveColumn.
        The database object that contains the sensitive column.


        :return: The object_name of this SensitiveColumn.
        :rtype: str
        """
        return self._object_name

    @object_name.setter
    def object_name(self, object_name):
        """
        Sets the object_name of this SensitiveColumn.
        The database object that contains the sensitive column.


        :param object_name: The object_name of this SensitiveColumn.
        :type: str
        """
        self._object_name = object_name

    @property
    def column_name(self):
        """
        **[Required]** Gets the column_name of this SensitiveColumn.
        The name of the sensitive column.


        :return: The column_name of this SensitiveColumn.
        :rtype: str
        """
        return self._column_name

    @column_name.setter
    def column_name(self, column_name):
        """
        Sets the column_name of this SensitiveColumn.
        The name of the sensitive column.


        :param column_name: The column_name of this SensitiveColumn.
        :type: str
        """
        self._column_name = column_name

    @property
    def object_type(self):
        """
        **[Required]** Gets the object_type of this SensitiveColumn.
        The type of the database object that contains the sensitive column.

        Allowed values for this property are: "TABLE", "EDITIONING_VIEW", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The object_type of this SensitiveColumn.
        :rtype: str
        """
        return self._object_type

    @object_type.setter
    def object_type(self, object_type):
        """
        Sets the object_type of this SensitiveColumn.
        The type of the database object that contains the sensitive column.


        :param object_type: The object_type of this SensitiveColumn.
        :type: str
        """
        allowed_values = ["TABLE", "EDITIONING_VIEW"]
        if not value_allowed_none_or_none_sentinel(object_type, allowed_values):
            object_type = 'UNKNOWN_ENUM_VALUE'
        self._object_type = object_type

    @property
    def data_type(self):
        """
        **[Required]** Gets the data_type of this SensitiveColumn.
        The data type of the sensitive column.


        :return: The data_type of this SensitiveColumn.
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """
        Sets the data_type of this SensitiveColumn.
        The data type of the sensitive column.


        :param data_type: The data_type of this SensitiveColumn.
        :type: str
        """
        self._data_type = data_type

    @property
    def status(self):
        """
        **[Required]** Gets the status of this SensitiveColumn.
        The status of the sensitive column. VALID means the column is considered sensitive. INVALID means the column
        is not considered sensitive. Tracking invalid columns in a sensitive data model helps ensure that an
        incremental data discovery job does not identify these columns as sensitive again.

        Allowed values for this property are: "VALID", "INVALID", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this SensitiveColumn.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this SensitiveColumn.
        The status of the sensitive column. VALID means the column is considered sensitive. INVALID means the column
        is not considered sensitive. Tracking invalid columns in a sensitive data model helps ensure that an
        incremental data discovery job does not identify these columns as sensitive again.


        :param status: The status of this SensitiveColumn.
        :type: str
        """
        allowed_values = ["VALID", "INVALID"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def sensitive_type_id(self):
        """
        Gets the sensitive_type_id of this SensitiveColumn.
        The OCID of the sensitive type associated with the sensitive column.


        :return: The sensitive_type_id of this SensitiveColumn.
        :rtype: str
        """
        return self._sensitive_type_id

    @sensitive_type_id.setter
    def sensitive_type_id(self, sensitive_type_id):
        """
        Sets the sensitive_type_id of this SensitiveColumn.
        The OCID of the sensitive type associated with the sensitive column.


        :param sensitive_type_id: The sensitive_type_id of this SensitiveColumn.
        :type: str
        """
        self._sensitive_type_id = sensitive_type_id

    @property
    def source(self):
        """
        **[Required]** Gets the source of this SensitiveColumn.
        The source of the sensitive column. DISCOVERY indicates that the column was added to the sensitive data model
        using a data discovery job. MANUAL indicates that the column was added manually.

        Allowed values for this property are: "MANUAL", "DISCOVERY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source of this SensitiveColumn.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this SensitiveColumn.
        The source of the sensitive column. DISCOVERY indicates that the column was added to the sensitive data model
        using a data discovery job. MANUAL indicates that the column was added manually.


        :param source: The source of this SensitiveColumn.
        :type: str
        """
        allowed_values = ["MANUAL", "DISCOVERY"]
        if not value_allowed_none_or_none_sentinel(source, allowed_values):
            source = 'UNKNOWN_ENUM_VALUE'
        self._source = source

    @property
    def parent_column_keys(self):
        """
        Gets the parent_column_keys of this SensitiveColumn.
        Unique keys identifying the columns that are parents of the sensitive column. At present, it tracks a single parent only.


        :return: The parent_column_keys of this SensitiveColumn.
        :rtype: list[str]
        """
        return self._parent_column_keys

    @parent_column_keys.setter
    def parent_column_keys(self, parent_column_keys):
        """
        Sets the parent_column_keys of this SensitiveColumn.
        Unique keys identifying the columns that are parents of the sensitive column. At present, it tracks a single parent only.


        :param parent_column_keys: The parent_column_keys of this SensitiveColumn.
        :type: list[str]
        """
        self._parent_column_keys = parent_column_keys

    @property
    def relation_type(self):
        """
        **[Required]** Gets the relation_type of this SensitiveColumn.
        The type of referential relationship the sensitive column has with its parent. NONE indicates that the
        sensitive column does not have a parent. DB_DEFINED indicates that the relationship is defined in the database
        dictionary. APP_DEFINED indicates that the relationship is defined at the application level and not in the database dictionary.

        Allowed values for this property are: "NONE", "APP_DEFINED", "DB_DEFINED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The relation_type of this SensitiveColumn.
        :rtype: str
        """
        return self._relation_type

    @relation_type.setter
    def relation_type(self, relation_type):
        """
        Sets the relation_type of this SensitiveColumn.
        The type of referential relationship the sensitive column has with its parent. NONE indicates that the
        sensitive column does not have a parent. DB_DEFINED indicates that the relationship is defined in the database
        dictionary. APP_DEFINED indicates that the relationship is defined at the application level and not in the database dictionary.


        :param relation_type: The relation_type of this SensitiveColumn.
        :type: str
        """
        allowed_values = ["NONE", "APP_DEFINED", "DB_DEFINED"]
        if not value_allowed_none_or_none_sentinel(relation_type, allowed_values):
            relation_type = 'UNKNOWN_ENUM_VALUE'
        self._relation_type = relation_type

    @property
    def estimated_data_value_count(self):
        """
        **[Required]** Gets the estimated_data_value_count of this SensitiveColumn.
        The estimated number of data values the column has in the associated database.


        :return: The estimated_data_value_count of this SensitiveColumn.
        :rtype: int
        """
        return self._estimated_data_value_count

    @estimated_data_value_count.setter
    def estimated_data_value_count(self, estimated_data_value_count):
        """
        Sets the estimated_data_value_count of this SensitiveColumn.
        The estimated number of data values the column has in the associated database.


        :param estimated_data_value_count: The estimated_data_value_count of this SensitiveColumn.
        :type: int
        """
        self._estimated_data_value_count = estimated_data_value_count

    @property
    def sample_data_values(self):
        """
        Gets the sample_data_values of this SensitiveColumn.
        Original data values collected for the sensitive column from the associated database. Sample data helps review
        the column and ensure that it actually contains sensitive data. Note that sample data is retrieved by a data
        discovery job only if the isSampleDataCollectionEnabled attribute is set to true. At present, only one data
        value is collected per sensitive column.


        :return: The sample_data_values of this SensitiveColumn.
        :rtype: list[str]
        """
        return self._sample_data_values

    @sample_data_values.setter
    def sample_data_values(self, sample_data_values):
        """
        Sets the sample_data_values of this SensitiveColumn.
        Original data values collected for the sensitive column from the associated database. Sample data helps review
        the column and ensure that it actually contains sensitive data. Note that sample data is retrieved by a data
        discovery job only if the isSampleDataCollectionEnabled attribute is set to true. At present, only one data
        value is collected per sensitive column.


        :param sample_data_values: The sample_data_values of this SensitiveColumn.
        :type: list[str]
        """
        self._sample_data_values = sample_data_values

    @property
    def app_defined_child_column_keys(self):
        """
        Gets the app_defined_child_column_keys of this SensitiveColumn.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.


        :return: The app_defined_child_column_keys of this SensitiveColumn.
        :rtype: list[str]
        """
        return self._app_defined_child_column_keys

    @app_defined_child_column_keys.setter
    def app_defined_child_column_keys(self, app_defined_child_column_keys):
        """
        Sets the app_defined_child_column_keys of this SensitiveColumn.
        Unique keys identifying the columns that are application-level (non-dictionary) children of the sensitive column.


        :param app_defined_child_column_keys: The app_defined_child_column_keys of this SensitiveColumn.
        :type: list[str]
        """
        self._app_defined_child_column_keys = app_defined_child_column_keys

    @property
    def db_defined_child_column_keys(self):
        """
        Gets the db_defined_child_column_keys of this SensitiveColumn.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.


        :return: The db_defined_child_column_keys of this SensitiveColumn.
        :rtype: list[str]
        """
        return self._db_defined_child_column_keys

    @db_defined_child_column_keys.setter
    def db_defined_child_column_keys(self, db_defined_child_column_keys):
        """
        Sets the db_defined_child_column_keys of this SensitiveColumn.
        Unique keys identifying the columns that are database-level (dictionary-defined) children of the sensitive column.


        :param db_defined_child_column_keys: The db_defined_child_column_keys of this SensitiveColumn.
        :type: list[str]
        """
        self._db_defined_child_column_keys = db_defined_child_column_keys

    @property
    def column_groups(self):
        """
        Gets the column_groups of this SensitiveColumn.
        The composite key groups to which the sensitive column belongs. If the column is part of a composite key,
        it's assigned a column group. It helps identify and manage referential relationships that involve composite keys.


        :return: The column_groups of this SensitiveColumn.
        :rtype: list[str]
        """
        return self._column_groups

    @column_groups.setter
    def column_groups(self, column_groups):
        """
        Sets the column_groups of this SensitiveColumn.
        The composite key groups to which the sensitive column belongs. If the column is part of a composite key,
        it's assigned a column group. It helps identify and manage referential relationships that involve composite keys.


        :param column_groups: The column_groups of this SensitiveColumn.
        :type: list[str]
        """
        self._column_groups = column_groups

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiffChunk(object):
    """
    Details about a group of changes.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiffChunk object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param base_line:
            The value to assign to the base_line property of this DiffChunk.
        :type base_line: int

        :param base_span:
            The value to assign to the base_span property of this DiffChunk.
        :type base_span: int

        :param target_line:
            The value to assign to the target_line property of this DiffChunk.
        :type target_line: int

        :param target_span:
            The value to assign to the target_span property of this DiffChunk.
        :type target_span: int

        :param diff_sections:
            The value to assign to the diff_sections property of this DiffChunk.
        :type diff_sections: list[oci.devops.models.DiffSection]

        """
        self.swagger_types = {
            'base_line': 'int',
            'base_span': 'int',
            'target_line': 'int',
            'target_span': 'int',
            'diff_sections': 'list[DiffSection]'
        }

        self.attribute_map = {
            'base_line': 'baseLine',
            'base_span': 'baseSpan',
            'target_line': 'targetLine',
            'target_span': 'targetSpan',
            'diff_sections': 'diffSections'
        }

        self._base_line = None
        self._base_span = None
        self._target_line = None
        self._target_span = None
        self._diff_sections = None

    @property
    def base_line(self):
        """
        Gets the base_line of this DiffChunk.
        Line number in base version where changes begin.


        :return: The base_line of this DiffChunk.
        :rtype: int
        """
        return self._base_line

    @base_line.setter
    def base_line(self, base_line):
        """
        Sets the base_line of this DiffChunk.
        Line number in base version where changes begin.


        :param base_line: The base_line of this DiffChunk.
        :type: int
        """
        self._base_line = base_line

    @property
    def base_span(self):
        """
        Gets the base_span of this DiffChunk.
        Number of lines chunk spans in base version.


        :return: The base_span of this DiffChunk.
        :rtype: int
        """
        return self._base_span

    @base_span.setter
    def base_span(self, base_span):
        """
        Sets the base_span of this DiffChunk.
        Number of lines chunk spans in base version.


        :param base_span: The base_span of this DiffChunk.
        :type: int
        """
        self._base_span = base_span

    @property
    def target_line(self):
        """
        Gets the target_line of this DiffChunk.
        Line number in target version where changes begin.


        :return: The target_line of this DiffChunk.
        :rtype: int
        """
        return self._target_line

    @target_line.setter
    def target_line(self, target_line):
        """
        Sets the target_line of this DiffChunk.
        Line number in target version where changes begin.


        :param target_line: The target_line of this DiffChunk.
        :type: int
        """
        self._target_line = target_line

    @property
    def target_span(self):
        """
        Gets the target_span of this DiffChunk.
        Number of lines chunk spans in target version.


        :return: The target_span of this DiffChunk.
        :rtype: int
        """
        return self._target_span

    @target_span.setter
    def target_span(self, target_span):
        """
        Sets the target_span of this DiffChunk.
        Number of lines chunk spans in target version.


        :param target_span: The target_span of this DiffChunk.
        :type: int
        """
        self._target_span = target_span

    @property
    def diff_sections(self):
        """
        Gets the diff_sections of this DiffChunk.
        List of difference section.


        :return: The diff_sections of this DiffChunk.
        :rtype: list[oci.devops.models.DiffSection]
        """
        return self._diff_sections

    @diff_sections.setter
    def diff_sections(self, diff_sections):
        """
        Sets the diff_sections of this DiffChunk.
        List of difference section.


        :param diff_sections: The diff_sections of this DiffChunk.
        :type: list[oci.devops.models.DiffSection]
        """
        self._diff_sections = diff_sections

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ModuleStreamOnManagedInstanceSummary(object):
    """
    Summary information pertaining to a module stream on a managed instance
    """

    #: A constant which can be used with the status property of a ModuleStreamOnManagedInstanceSummary.
    #: This constant has a value of "ENABLED"
    STATUS_ENABLED = "ENABLED"

    #: A constant which can be used with the status property of a ModuleStreamOnManagedInstanceSummary.
    #: This constant has a value of "DISABLED"
    STATUS_DISABLED = "DISABLED"

    #: A constant which can be used with the status property of a ModuleStreamOnManagedInstanceSummary.
    #: This constant has a value of "ACTIVE"
    STATUS_ACTIVE = "ACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new ModuleStreamOnManagedInstanceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param module_name:
            The value to assign to the module_name property of this ModuleStreamOnManagedInstanceSummary.
        :type module_name: str

        :param stream_name:
            The value to assign to the stream_name property of this ModuleStreamOnManagedInstanceSummary.
        :type stream_name: str

        :param status:
            The value to assign to the status property of this ModuleStreamOnManagedInstanceSummary.
            Allowed values for this property are: "ENABLED", "DISABLED", "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        :param profiles:
            The value to assign to the profiles property of this ModuleStreamOnManagedInstanceSummary.
        :type profiles: list[oci.os_management.models.ModuleStreamProfileOnManagedInstanceSummary]

        :param software_source_id:
            The value to assign to the software_source_id property of this ModuleStreamOnManagedInstanceSummary.
        :type software_source_id: str

        :param time_modified:
            The value to assign to the time_modified property of this ModuleStreamOnManagedInstanceSummary.
        :type time_modified: datetime

        """
        self.swagger_types = {
            'module_name': 'str',
            'stream_name': 'str',
            'status': 'str',
            'profiles': 'list[ModuleStreamProfileOnManagedInstanceSummary]',
            'software_source_id': 'str',
            'time_modified': 'datetime'
        }

        self.attribute_map = {
            'module_name': 'moduleName',
            'stream_name': 'streamName',
            'status': 'status',
            'profiles': 'profiles',
            'software_source_id': 'softwareSourceId',
            'time_modified': 'timeModified'
        }

        self._module_name = None
        self._stream_name = None
        self._status = None
        self._profiles = None
        self._software_source_id = None
        self._time_modified = None

    @property
    def module_name(self):
        """
        **[Required]** Gets the module_name of this ModuleStreamOnManagedInstanceSummary.
        The name of the module that contains the stream.


        :return: The module_name of this ModuleStreamOnManagedInstanceSummary.
        :rtype: str
        """
        return self._module_name

    @module_name.setter
    def module_name(self, module_name):
        """
        Sets the module_name of this ModuleStreamOnManagedInstanceSummary.
        The name of the module that contains the stream.


        :param module_name: The module_name of this ModuleStreamOnManagedInstanceSummary.
        :type: str
        """
        self._module_name = module_name

    @property
    def stream_name(self):
        """
        **[Required]** Gets the stream_name of this ModuleStreamOnManagedInstanceSummary.
        The name of the stream.


        :return: The stream_name of this ModuleStreamOnManagedInstanceSummary.
        :rtype: str
        """
        return self._stream_name

    @stream_name.setter
    def stream_name(self, stream_name):
        """
        Sets the stream_name of this ModuleStreamOnManagedInstanceSummary.
        The name of the stream.


        :param stream_name: The stream_name of this ModuleStreamOnManagedInstanceSummary.
        :type: str
        """
        self._stream_name = stream_name

    @property
    def status(self):
        """
        **[Required]** Gets the status of this ModuleStreamOnManagedInstanceSummary.
        The status of the stream

        A stream with the \"ENABLED\" status can be used as a source for installing
        profiles.  Streams with this status are also \"ACTIVE\".

        A stream with the \"DISABLED\" status cannot be the source for installing
        profiles.  To install profiles and packages from this stream, it must be
        enabled.

        A stream with the \"ACTIVE\" status can be used as a source for installing
        profiles.  The packages that comprise the stream are also used when a
        matching package is installed directly.  In general, a stream can have
        this status if it is the default stream for the module and no stream has
        been explicitly enabled.

        Allowed values for this property are: "ENABLED", "DISABLED", "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ModuleStreamOnManagedInstanceSummary.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ModuleStreamOnManagedInstanceSummary.
        The status of the stream

        A stream with the \"ENABLED\" status can be used as a source for installing
        profiles.  Streams with this status are also \"ACTIVE\".

        A stream with the \"DISABLED\" status cannot be the source for installing
        profiles.  To install profiles and packages from this stream, it must be
        enabled.

        A stream with the \"ACTIVE\" status can be used as a source for installing
        profiles.  The packages that comprise the stream are also used when a
        matching package is installed directly.  In general, a stream can have
        this status if it is the default stream for the module and no stream has
        been explicitly enabled.


        :param status: The status of this ModuleStreamOnManagedInstanceSummary.
        :type: str
        """
        allowed_values = ["ENABLED", "DISABLED", "ACTIVE"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    @property
    def profiles(self):
        """
        Gets the profiles of this ModuleStreamOnManagedInstanceSummary.
        The set of profiles that the module stream contains.


        :return: The profiles of this ModuleStreamOnManagedInstanceSummary.
        :rtype: list[oci.os_management.models.ModuleStreamProfileOnManagedInstanceSummary]
        """
        return self._profiles

    @profiles.setter
    def profiles(self, profiles):
        """
        Sets the profiles of this ModuleStreamOnManagedInstanceSummary.
        The set of profiles that the module stream contains.


        :param profiles: The profiles of this ModuleStreamOnManagedInstanceSummary.
        :type: list[oci.os_management.models.ModuleStreamProfileOnManagedInstanceSummary]
        """
        self._profiles = profiles

    @property
    def software_source_id(self):
        """
        Gets the software_source_id of this ModuleStreamOnManagedInstanceSummary.
        The OCID of the software source that provides this module stream.


        :return: The software_source_id of this ModuleStreamOnManagedInstanceSummary.
        :rtype: str
        """
        return self._software_source_id

    @software_source_id.setter
    def software_source_id(self, software_source_id):
        """
        Sets the software_source_id of this ModuleStreamOnManagedInstanceSummary.
        The OCID of the software source that provides this module stream.


        :param software_source_id: The software_source_id of this ModuleStreamOnManagedInstanceSummary.
        :type: str
        """
        self._software_source_id = software_source_id

    @property
    def time_modified(self):
        """
        Gets the time_modified of this ModuleStreamOnManagedInstanceSummary.
        The date and time of the last status change for this profile, as
        described in `RFC 3339`__,
        section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :return: The time_modified of this ModuleStreamOnManagedInstanceSummary.
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """
        Sets the time_modified of this ModuleStreamOnManagedInstanceSummary.
        The date and time of the last status change for this profile, as
        described in `RFC 3339`__,
        section 14.29.

        __ https://tools.ietf.org/rfc/rfc3339


        :param time_modified: The time_modified of this ModuleStreamOnManagedInstanceSummary.
        :type: datetime
        """
        self._time_modified = time_modified

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SubscribedServicePaymentTerm(object):
    """
    Payment Term details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SubscribedServicePaymentTerm object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this SubscribedServicePaymentTerm.
        :type name: str

        :param value:
            The value to assign to the value property of this SubscribedServicePaymentTerm.
        :type value: str

        :param description:
            The value to assign to the description property of this SubscribedServicePaymentTerm.
        :type description: str

        :param is_active:
            The value to assign to the is_active property of this SubscribedServicePaymentTerm.
        :type is_active: bool

        :param time_created:
            The value to assign to the time_created property of this SubscribedServicePaymentTerm.
        :type time_created: datetime

        :param created_by:
            The value to assign to the created_by property of this SubscribedServicePaymentTerm.
        :type created_by: str

        :param time_updated:
            The value to assign to the time_updated property of this SubscribedServicePaymentTerm.
        :type time_updated: datetime

        :param updated_by:
            The value to assign to the updated_by property of this SubscribedServicePaymentTerm.
        :type updated_by: str

        """
        self.swagger_types = {
            'name': 'str',
            'value': 'str',
            'description': 'str',
            'is_active': 'bool',
            'time_created': 'datetime',
            'created_by': 'str',
            'time_updated': 'datetime',
            'updated_by': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'value': 'value',
            'description': 'description',
            'is_active': 'isActive',
            'time_created': 'timeCreated',
            'created_by': 'createdBy',
            'time_updated': 'timeUpdated',
            'updated_by': 'updatedBy'
        }

        self._name = None
        self._value = None
        self._description = None
        self._is_active = None
        self._time_created = None
        self._created_by = None
        self._time_updated = None
        self._updated_by = None

    @property
    def name(self):
        """
        Gets the name of this SubscribedServicePaymentTerm.
        Payment Term name


        :return: The name of this SubscribedServicePaymentTerm.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this SubscribedServicePaymentTerm.
        Payment Term name


        :param name: The name of this SubscribedServicePaymentTerm.
        :type: str
        """
        self._name = name

    @property
    def value(self):
        """
        Gets the value of this SubscribedServicePaymentTerm.
        Payment Term value


        :return: The value of this SubscribedServicePaymentTerm.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SubscribedServicePaymentTerm.
        Payment Term value


        :param value: The value of this SubscribedServicePaymentTerm.
        :type: str
        """
        self._value = value

    @property
    def description(self):
        """
        Gets the description of this SubscribedServicePaymentTerm.
        Payment term Description


        :return: The description of this SubscribedServicePaymentTerm.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this SubscribedServicePaymentTerm.
        Payment term Description


        :param description: The description of this SubscribedServicePaymentTerm.
        :type: str
        """
        self._description = description

    @property
    def is_active(self):
        """
        Gets the is_active of this SubscribedServicePaymentTerm.
        Payment term active flag


        :return: The is_active of this SubscribedServicePaymentTerm.
        :rtype: bool
        """
        return self._is_active

    @is_active.setter
    def is_active(self, is_active):
        """
        Sets the is_active of this SubscribedServicePaymentTerm.
        Payment term active flag


        :param is_active: The is_active of this SubscribedServicePaymentTerm.
        :type: bool
        """
        self._is_active = is_active

    @property
    def time_created(self):
        """
        Gets the time_created of this SubscribedServicePaymentTerm.
        Payment term last update date


        :return: The time_created of this SubscribedServicePaymentTerm.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this SubscribedServicePaymentTerm.
        Payment term last update date


        :param time_created: The time_created of this SubscribedServicePaymentTerm.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def created_by(self):
        """
        Gets the created_by of this SubscribedServicePaymentTerm.
        User that created the Payment term


        :return: The created_by of this SubscribedServicePaymentTerm.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this SubscribedServicePaymentTerm.
        User that created the Payment term


        :param created_by: The created_by of this SubscribedServicePaymentTerm.
        :type: str
        """
        self._created_by = created_by

    @property
    def time_updated(self):
        """
        Gets the time_updated of this SubscribedServicePaymentTerm.
        Payment term last update date


        :return: The time_updated of this SubscribedServicePaymentTerm.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this SubscribedServicePaymentTerm.
        Payment term last update date


        :param time_updated: The time_updated of this SubscribedServicePaymentTerm.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def updated_by(self):
        """
        Gets the updated_by of this SubscribedServicePaymentTerm.
        User that updated the Payment term


        :return: The updated_by of this SubscribedServicePaymentTerm.
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """
        Sets the updated_by of this SubscribedServicePaymentTerm.
        User that updated the Payment term


        :param updated_by: The updated_by of this SubscribedServicePaymentTerm.
        :type: str
        """
        self._updated_by = updated_by

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .allowed_security_configuration import AllowedSecurityConfiguration
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class EgressSecurityListConfiguration(AllowedSecurityConfiguration):
    """
    Defines the subnet egress security list configuration that allowed the traffic.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new EgressSecurityListConfiguration object with values from keyword arguments. The default value of the :py:attr:`~oci.vn_monitoring.models.EgressSecurityListConfiguration.type` attribute
        of this class is ``EGRESS_SECURITY_LIST`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this EgressSecurityListConfiguration.
            Allowed values for this property are: "NSG", "STATEFUL_NSG", "INGRESS_SECURITY_LIST", "STATEFUL_INGRESS_SECURITY_LIST", "EGRESS_SECURITY_LIST", "STATEFUL_EGRESS_SECURITY_LIST"
        :type type: str

        :param security_list_id:
            The value to assign to the security_list_id property of this EgressSecurityListConfiguration.
        :type security_list_id: str

        :param security_rule:
            The value to assign to the security_rule property of this EgressSecurityListConfiguration.
        :type security_rule: oci.vn_monitoring.models.EgressSecurityRule

        """
        self.swagger_types = {
            'type': 'str',
            'security_list_id': 'str',
            'security_rule': 'EgressSecurityRule'
        }

        self.attribute_map = {
            'type': 'type',
            'security_list_id': 'securityListId',
            'security_rule': 'securityRule'
        }

        self._type = None
        self._security_list_id = None
        self._security_rule = None
        self._type = 'EGRESS_SECURITY_LIST'

    @property
    def security_list_id(self):
        """
        **[Required]** Gets the security_list_id of this EgressSecurityListConfiguration.
        The `OCID`__ of the security
        list that allowed the traffic.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The security_list_id of this EgressSecurityListConfiguration.
        :rtype: str
        """
        return self._security_list_id

    @security_list_id.setter
    def security_list_id(self, security_list_id):
        """
        Sets the security_list_id of this EgressSecurityListConfiguration.
        The `OCID`__ of the security
        list that allowed the traffic.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param security_list_id: The security_list_id of this EgressSecurityListConfiguration.
        :type: str
        """
        self._security_list_id = security_list_id

    @property
    def security_rule(self):
        """
        **[Required]** Gets the security_rule of this EgressSecurityListConfiguration.

        :return: The security_rule of this EgressSecurityListConfiguration.
        :rtype: oci.vn_monitoring.models.EgressSecurityRule
        """
        return self._security_rule

    @security_rule.setter
    def security_rule(self, security_rule):
        """
        Sets the security_rule of this EgressSecurityListConfiguration.

        :param security_rule: The security_rule of this EgressSecurityListConfiguration.
        :type: oci.vn_monitoring.models.EgressSecurityRule
        """
        self._security_rule = security_rule

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateIdentityProviderDetails(object):
    """
    UpdateIdentityProviderDetails model.
    """

    #: A constant which can be used with the protocol property of a UpdateIdentityProviderDetails.
    #: This constant has a value of "SAML2"
    PROTOCOL_SAML2 = "SAML2"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateIdentityProviderDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.identity.models.UpdateSaml2IdentityProviderDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param protocol:
            The value to assign to the protocol property of this UpdateIdentityProviderDetails.
            Allowed values for this property are: "SAML2"
        :type protocol: str

        :param description:
            The value to assign to the description property of this UpdateIdentityProviderDetails.
        :type description: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateIdentityProviderDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateIdentityProviderDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'protocol': 'str',
            'description': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'protocol': 'protocol',
            'description': 'description',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._protocol = None
        self._description = None
        self._freeform_tags = None
        self._defined_tags = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['protocol']

        if type == 'SAML2':
            return 'UpdateSaml2IdentityProviderDetails'
        else:
            return 'UpdateIdentityProviderDetails'

    @property
    def protocol(self):
        """
        **[Required]** Gets the protocol of this UpdateIdentityProviderDetails.
        The protocol used for federation.

        Example: `SAML2`

        Allowed values for this property are: "SAML2"


        :return: The protocol of this UpdateIdentityProviderDetails.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this UpdateIdentityProviderDetails.
        The protocol used for federation.

        Example: `SAML2`


        :param protocol: The protocol of this UpdateIdentityProviderDetails.
        :type: str
        """
        allowed_values = ["SAML2"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            raise ValueError(
                "Invalid value for `protocol`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._protocol = protocol

    @property
    def description(self):
        """
        Gets the description of this UpdateIdentityProviderDetails.
        The description you assign to the `IdentityProvider`. Does not have to
        be unique, and it's changeable.


        :return: The description of this UpdateIdentityProviderDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateIdentityProviderDetails.
        The description you assign to the `IdentityProvider`. Does not have to
        be unique, and it's changeable.


        :param description: The description of this UpdateIdentityProviderDetails.
        :type: str
        """
        self._description = description

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateIdentityProviderDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateIdentityProviderDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateIdentityProviderDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateIdentityProviderDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateIdentityProviderDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateIdentityProviderDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateIdentityProviderDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateIdentityProviderDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbstractDataOperationConfig(object):
    """
    The information about the data operation.
    """

    #: A constant which can be used with the model_type property of a AbstractDataOperationConfig.
    #: This constant has a value of "READ_OPERATION_CONFIG"
    MODEL_TYPE_READ_OPERATION_CONFIG = "READ_OPERATION_CONFIG"

    #: A constant which can be used with the model_type property of a AbstractDataOperationConfig.
    #: This constant has a value of "WRITE_OPERATION_CONFIG"
    MODEL_TYPE_WRITE_OPERATION_CONFIG = "WRITE_OPERATION_CONFIG"

    def __init__(self, **kwargs):
        """
        Initializes a new AbstractDataOperationConfig object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.WriteOperationConfig`
        * :class:`~oci.data_integration.models.ReadOperationConfig`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this AbstractDataOperationConfig.
            Allowed values for this property are: "READ_OPERATION_CONFIG", "WRITE_OPERATION_CONFIG"
        :type model_type: str

        :param metadata_config_properties:
            The value to assign to the metadata_config_properties property of this AbstractDataOperationConfig.
        :type metadata_config_properties: dict(str, str)

        :param derived_attributes:
            The value to assign to the derived_attributes property of this AbstractDataOperationConfig.
        :type derived_attributes: dict(str, str)

        :param call_attribute:
            The value to assign to the call_attribute property of this AbstractDataOperationConfig.
        :type call_attribute: oci.data_integration.models.BipCallAttribute

        """
        self.swagger_types = {
            'model_type': 'str',
            'metadata_config_properties': 'dict(str, str)',
            'derived_attributes': 'dict(str, str)',
            'call_attribute': 'BipCallAttribute'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'metadata_config_properties': 'metadataConfigProperties',
            'derived_attributes': 'derivedAttributes',
            'call_attribute': 'callAttribute'
        }

        self._model_type = None
        self._metadata_config_properties = None
        self._derived_attributes = None
        self._call_attribute = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'WRITE_OPERATION_CONFIG':
            return 'WriteOperationConfig'

        if type == 'READ_OPERATION_CONFIG':
            return 'ReadOperationConfig'
        else:
            return 'AbstractDataOperationConfig'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this AbstractDataOperationConfig.
        The type of data operation.

        Allowed values for this property are: "READ_OPERATION_CONFIG", "WRITE_OPERATION_CONFIG"


        :return: The model_type of this AbstractDataOperationConfig.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this AbstractDataOperationConfig.
        The type of data operation.


        :param model_type: The model_type of this AbstractDataOperationConfig.
        :type: str
        """
        allowed_values = ["READ_OPERATION_CONFIG", "WRITE_OPERATION_CONFIG"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            raise ValueError(
                "Invalid value for `model_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._model_type = model_type

    @property
    def metadata_config_properties(self):
        """
        Gets the metadata_config_properties of this AbstractDataOperationConfig.
        This map is used for passing extra metatdata configuration that is required by read / write operation.


        :return: The metadata_config_properties of this AbstractDataOperationConfig.
        :rtype: dict(str, str)
        """
        return self._metadata_config_properties

    @metadata_config_properties.setter
    def metadata_config_properties(self, metadata_config_properties):
        """
        Sets the metadata_config_properties of this AbstractDataOperationConfig.
        This map is used for passing extra metatdata configuration that is required by read / write operation.


        :param metadata_config_properties: The metadata_config_properties of this AbstractDataOperationConfig.
        :type: dict(str, str)
        """
        self._metadata_config_properties = metadata_config_properties

    @property
    def derived_attributes(self):
        """
        Gets the derived_attributes of this AbstractDataOperationConfig.
        this map is used for passing BIP report parameter values.


        :return: The derived_attributes of this AbstractDataOperationConfig.
        :rtype: dict(str, str)
        """
        return self._derived_attributes

    @derived_attributes.setter
    def derived_attributes(self, derived_attributes):
        """
        Sets the derived_attributes of this AbstractDataOperationConfig.
        this map is used for passing BIP report parameter values.


        :param derived_attributes: The derived_attributes of this AbstractDataOperationConfig.
        :type: dict(str, str)
        """
        self._derived_attributes = derived_attributes

    @property
    def call_attribute(self):
        """
        Gets the call_attribute of this AbstractDataOperationConfig.

        :return: The call_attribute of this AbstractDataOperationConfig.
        :rtype: oci.data_integration.models.BipCallAttribute
        """
        return self._call_attribute

    @call_attribute.setter
    def call_attribute(self, call_attribute):
        """
        Sets the call_attribute of this AbstractDataOperationConfig.

        :param call_attribute: The call_attribute of this AbstractDataOperationConfig.
        :type: oci.data_integration.models.BipCallAttribute
        """
        self._call_attribute = call_attribute

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RepositoryMirrorRecord(object):
    """
    Object containing information about a mirror record.
    """

    #: A constant which can be used with the mirror_status property of a RepositoryMirrorRecord.
    #: This constant has a value of "NONE"
    MIRROR_STATUS_NONE = "NONE"

    #: A constant which can be used with the mirror_status property of a RepositoryMirrorRecord.
    #: This constant has a value of "QUEUED"
    MIRROR_STATUS_QUEUED = "QUEUED"

    #: A constant which can be used with the mirror_status property of a RepositoryMirrorRecord.
    #: This constant has a value of "RUNNING"
    MIRROR_STATUS_RUNNING = "RUNNING"

    #: A constant which can be used with the mirror_status property of a RepositoryMirrorRecord.
    #: This constant has a value of "PASSED"
    MIRROR_STATUS_PASSED = "PASSED"

    #: A constant which can be used with the mirror_status property of a RepositoryMirrorRecord.
    #: This constant has a value of "FAILED"
    MIRROR_STATUS_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new RepositoryMirrorRecord object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param mirror_status:
            The value to assign to the mirror_status property of this RepositoryMirrorRecord.
            Allowed values for this property are: "NONE", "QUEUED", "RUNNING", "PASSED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type mirror_status: str

        :param work_request_id:
            The value to assign to the work_request_id property of this RepositoryMirrorRecord.
        :type work_request_id: str

        :param time_enqueued:
            The value to assign to the time_enqueued property of this RepositoryMirrorRecord.
        :type time_enqueued: datetime

        :param time_started:
            The value to assign to the time_started property of this RepositoryMirrorRecord.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this RepositoryMirrorRecord.
        :type time_ended: datetime

        """
        self.swagger_types = {
            'mirror_status': 'str',
            'work_request_id': 'str',
            'time_enqueued': 'datetime',
            'time_started': 'datetime',
            'time_ended': 'datetime'
        }

        self.attribute_map = {
            'mirror_status': 'mirrorStatus',
            'work_request_id': 'workRequestId',
            'time_enqueued': 'timeEnqueued',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded'
        }

        self._mirror_status = None
        self._work_request_id = None
        self._time_enqueued = None
        self._time_started = None
        self._time_ended = None

    @property
    def mirror_status(self):
        """
        **[Required]** Gets the mirror_status of this RepositoryMirrorRecord.
        Mirror status of current mirror entry.
        QUEUED - Mirroring Queued
        RUNNING - Mirroring is Running
        PASSED - Mirroring Passed
        FAILED - Mirroring Failed

        Allowed values for this property are: "NONE", "QUEUED", "RUNNING", "PASSED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The mirror_status of this RepositoryMirrorRecord.
        :rtype: str
        """
        return self._mirror_status

    @mirror_status.setter
    def mirror_status(self, mirror_status):
        """
        Sets the mirror_status of this RepositoryMirrorRecord.
        Mirror status of current mirror entry.
        QUEUED - Mirroring Queued
        RUNNING - Mirroring is Running
        PASSED - Mirroring Passed
        FAILED - Mirroring Failed


        :param mirror_status: The mirror_status of this RepositoryMirrorRecord.
        :type: str
        """
        allowed_values = ["NONE", "QUEUED", "RUNNING", "PASSED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(mirror_status, allowed_values):
            mirror_status = 'UNKNOWN_ENUM_VALUE'
        self._mirror_status = mirror_status

    @property
    def work_request_id(self):
        """
        Gets the work_request_id of this RepositoryMirrorRecord.
        Workrequest ID to track current mirror operation.


        :return: The work_request_id of this RepositoryMirrorRecord.
        :rtype: str
        """
        return self._work_request_id

    @work_request_id.setter
    def work_request_id(self, work_request_id):
        """
        Sets the work_request_id of this RepositoryMirrorRecord.
        Workrequest ID to track current mirror operation.


        :param work_request_id: The work_request_id of this RepositoryMirrorRecord.
        :type: str
        """
        self._work_request_id = work_request_id

    @property
    def time_enqueued(self):
        """
        Gets the time_enqueued of this RepositoryMirrorRecord.
        The time to enqueue a mirror operation.


        :return: The time_enqueued of this RepositoryMirrorRecord.
        :rtype: datetime
        """
        return self._time_enqueued

    @time_enqueued.setter
    def time_enqueued(self, time_enqueued):
        """
        Sets the time_enqueued of this RepositoryMirrorRecord.
        The time to enqueue a mirror operation.


        :param time_enqueued: The time_enqueued of this RepositoryMirrorRecord.
        :type: datetime
        """
        self._time_enqueued = time_enqueued

    @property
    def time_started(self):
        """
        Gets the time_started of this RepositoryMirrorRecord.
        The time to start a mirror operation.


        :return: The time_started of this RepositoryMirrorRecord.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this RepositoryMirrorRecord.
        The time to start a mirror operation.


        :param time_started: The time_started of this RepositoryMirrorRecord.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        Gets the time_ended of this RepositoryMirrorRecord.
        The time taken to complete a mirror operation. Value is null if not completed.


        :return: The time_ended of this RepositoryMirrorRecord.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this RepositoryMirrorRecord.
        The time taken to complete a mirror operation. Value is null if not completed.


        :param time_ended: The time_ended of this RepositoryMirrorRecord.
        :type: datetime
        """
        self._time_ended = time_ended

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InteractionSummary(object):
    """
    Summary of access request customer and operator conversation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InteractionSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this InteractionSummary.
        :type id: str

        :param user_id:
            The value to assign to the user_id property of this InteractionSummary.
        :type user_id: str

        :param user_name:
            The value to assign to the user_name property of this InteractionSummary.
        :type user_name: str

        :param message:
            The value to assign to the message property of this InteractionSummary.
        :type message: str

        :param user_type:
            The value to assign to the user_type property of this InteractionSummary.
        :type user_type: str

        :param time_of_conversation:
            The value to assign to the time_of_conversation property of this InteractionSummary.
        :type time_of_conversation: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'user_id': 'str',
            'user_name': 'str',
            'message': 'str',
            'user_type': 'str',
            'time_of_conversation': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'user_id': 'userId',
            'user_name': 'userName',
            'message': 'message',
            'user_type': 'userType',
            'time_of_conversation': 'timeOfConversation'
        }

        self._id = None
        self._user_id = None
        self._user_name = None
        self._message = None
        self._user_type = None
        self._time_of_conversation = None

    @property
    def id(self):
        """
        Gets the id of this InteractionSummary.
        The uniqueId of the message.


        :return: The id of this InteractionSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InteractionSummary.
        The uniqueId of the message.


        :param id: The id of this InteractionSummary.
        :type: str
        """
        self._id = id

    @property
    def user_id(self):
        """
        Gets the user_id of this InteractionSummary.
        customer or operator id who is part of this conversation.


        :return: The user_id of this InteractionSummary.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this InteractionSummary.
        customer or operator id who is part of this conversation.


        :param user_id: The user_id of this InteractionSummary.
        :type: str
        """
        self._user_id = user_id

    @property
    def user_name(self):
        """
        Gets the user_name of this InteractionSummary.
        customer or operator Name who is part of this conversation.


        :return: The user_name of this InteractionSummary.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this InteractionSummary.
        customer or operator Name who is part of this conversation.


        :param user_name: The user_name of this InteractionSummary.
        :type: str
        """
        self._user_name = user_name

    @property
    def message(self):
        """
        Gets the message of this InteractionSummary.
        contains the information exchanged between operator and customer.


        :return: The message of this InteractionSummary.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this InteractionSummary.
        contains the information exchanged between operator and customer.


        :param message: The message of this InteractionSummary.
        :type: str
        """
        self._message = message

    @property
    def user_type(self):
        """
        Gets the user_type of this InteractionSummary.
        Whether the userConversation is an operator or customer.


        :return: The user_type of this InteractionSummary.
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """
        Sets the user_type of this InteractionSummary.
        Whether the userConversation is an operator or customer.


        :param user_type: The user_type of this InteractionSummary.
        :type: str
        """
        self._user_type = user_type

    @property
    def time_of_conversation(self):
        """
        Gets the time_of_conversation of this InteractionSummary.
        Time when the conversation happened in `RFC 3339`__timestamp format. Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_of_conversation of this InteractionSummary.
        :rtype: datetime
        """
        return self._time_of_conversation

    @time_of_conversation.setter
    def time_of_conversation(self, time_of_conversation):
        """
        Sets the time_of_conversation of this InteractionSummary.
        Time when the conversation happened in `RFC 3339`__timestamp format. Example: '2020-05-22T21:10:29.600Z'

        __ https://tools.ietf.org/html/rfc3339


        :param time_of_conversation: The time_of_conversation of this InteractionSummary.
        :type: datetime
        """
        self._time_of_conversation = time_of_conversation

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NetworkConfiguration(object):
    """
    Details of the network configuration.
    """

    #: A constant which can be used with the protocol property of a NetworkConfiguration.
    #: This constant has a value of "ICMP"
    PROTOCOL_ICMP = "ICMP"

    #: A constant which can be used with the protocol property of a NetworkConfiguration.
    #: This constant has a value of "TCP"
    PROTOCOL_TCP = "TCP"

    #: A constant which can be used with the probe_mode property of a NetworkConfiguration.
    #: This constant has a value of "SACK"
    PROBE_MODE_SACK = "SACK"

    #: A constant which can be used with the probe_mode property of a NetworkConfiguration.
    #: This constant has a value of "SYN"
    PROBE_MODE_SYN = "SYN"

    def __init__(self, **kwargs):
        """
        Initializes a new NetworkConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param number_of_hops:
            The value to assign to the number_of_hops property of this NetworkConfiguration.
        :type number_of_hops: int

        :param probe_per_hop:
            The value to assign to the probe_per_hop property of this NetworkConfiguration.
        :type probe_per_hop: int

        :param transmission_rate:
            The value to assign to the transmission_rate property of this NetworkConfiguration.
        :type transmission_rate: int

        :param protocol:
            The value to assign to the protocol property of this NetworkConfiguration.
            Allowed values for this property are: "ICMP", "TCP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type protocol: str

        :param probe_mode:
            The value to assign to the probe_mode property of this NetworkConfiguration.
            Allowed values for this property are: "SACK", "SYN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type probe_mode: str

        """
        self.swagger_types = {
            'number_of_hops': 'int',
            'probe_per_hop': 'int',
            'transmission_rate': 'int',
            'protocol': 'str',
            'probe_mode': 'str'
        }

        self.attribute_map = {
            'number_of_hops': 'numberOfHops',
            'probe_per_hop': 'probePerHop',
            'transmission_rate': 'transmissionRate',
            'protocol': 'protocol',
            'probe_mode': 'probeMode'
        }

        self._number_of_hops = None
        self._probe_per_hop = None
        self._transmission_rate = None
        self._protocol = None
        self._probe_mode = None

    @property
    def number_of_hops(self):
        """
        Gets the number_of_hops of this NetworkConfiguration.
        Number of hops.


        :return: The number_of_hops of this NetworkConfiguration.
        :rtype: int
        """
        return self._number_of_hops

    @number_of_hops.setter
    def number_of_hops(self, number_of_hops):
        """
        Sets the number_of_hops of this NetworkConfiguration.
        Number of hops.


        :param number_of_hops: The number_of_hops of this NetworkConfiguration.
        :type: int
        """
        self._number_of_hops = number_of_hops

    @property
    def probe_per_hop(self):
        """
        Gets the probe_per_hop of this NetworkConfiguration.
        Number of probes per hop.


        :return: The probe_per_hop of this NetworkConfiguration.
        :rtype: int
        """
        return self._probe_per_hop

    @probe_per_hop.setter
    def probe_per_hop(self, probe_per_hop):
        """
        Sets the probe_per_hop of this NetworkConfiguration.
        Number of probes per hop.


        :param probe_per_hop: The probe_per_hop of this NetworkConfiguration.
        :type: int
        """
        self._probe_per_hop = probe_per_hop

    @property
    def transmission_rate(self):
        """
        Gets the transmission_rate of this NetworkConfiguration.
        Number of probe packets sent out simultaneously.


        :return: The transmission_rate of this NetworkConfiguration.
        :rtype: int
        """
        return self._transmission_rate

    @transmission_rate.setter
    def transmission_rate(self, transmission_rate):
        """
        Sets the transmission_rate of this NetworkConfiguration.
        Number of probe packets sent out simultaneously.


        :param transmission_rate: The transmission_rate of this NetworkConfiguration.
        :type: int
        """
        self._transmission_rate = transmission_rate

    @property
    def protocol(self):
        """
        Gets the protocol of this NetworkConfiguration.
        Type of protocol.

        Allowed values for this property are: "ICMP", "TCP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The protocol of this NetworkConfiguration.
        :rtype: str
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """
        Sets the protocol of this NetworkConfiguration.
        Type of protocol.


        :param protocol: The protocol of this NetworkConfiguration.
        :type: str
        """
        allowed_values = ["ICMP", "TCP"]
        if not value_allowed_none_or_none_sentinel(protocol, allowed_values):
            protocol = 'UNKNOWN_ENUM_VALUE'
        self._protocol = protocol

    @property
    def probe_mode(self):
        """
        Gets the probe_mode of this NetworkConfiguration.
        Type of probe mode when TCP protocol is selected.

        Allowed values for this property are: "SACK", "SYN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The probe_mode of this NetworkConfiguration.
        :rtype: str
        """
        return self._probe_mode

    @probe_mode.setter
    def probe_mode(self, probe_mode):
        """
        Sets the probe_mode of this NetworkConfiguration.
        Type of probe mode when TCP protocol is selected.


        :param probe_mode: The probe_mode of this NetworkConfiguration.
        :type: str
        """
        allowed_values = ["SACK", "SYN"]
        if not value_allowed_none_or_none_sentinel(probe_mode, allowed_values):
            probe_mode = 'UNKNOWN_ENUM_VALUE'
        self._probe_mode = probe_mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
